import QtQuick 1.0
import com.nokia.meego 1.0
import QtMobility.contacts 1.1
import "CommonUtil.js" as Util
import RoundedImage 1.0

Item {
    id: addressBookPage
    width: parent.width
    height: parent.height

    Connections {
        target: context
        onSendSmsFinished: {
            indicator.running = false;
            indicator.visible = false;
            if(type === 0)
            {
                pageStack.pop();
            }
            else
            {
                //show warning
            }

        }
    }


    Image {
        id: backgroudImg
        width: parent.width
        height: parent.height
        source: "../image/home_bg.png"
    }

    ListView {
        id:contactList
        width: parent.width
        anchors.top: pageTopBar.bottom
        anchors.topMargin: 15
        anchors.bottom: pageBottomBar.top
        clip: true

        model:ContactModel {
            filter: IntersectionFilter {
                DetailFilter {
                    detail:ContactDetail.PhoneNumber
                }
            }

            sortOrders: [
               SortOrder {
                  detail:ContactDetail.Organization
                  field:Organization.Name
                  direction:Qt.AscendingOrder
               },
               SortOrder {
                  detail:ContactDetail.Name
                  field:Name.FirstName
                  direction:Qt.AscendingOrder
               }
            ]
        }

        delegate: Item {
            height: 100
            anchors.left: parent.left
            anchors.leftMargin: 20
            anchors.right: parent.right
            anchors.rightMargin: 20

            Row {
                spacing: 30

                Item {
                    id: avatar
                    width: 80;
                    height: width;
                    smooth: true
                    RoundedImage {
                        id: defaultImage
                        width: parent.width
                        height: width
                        anchors.centerIn: parent
                        source: Util.getRandomDefaultThumb();
                        engine: declarativeEngine
                    }
                    RoundedImage {
                        id: stationImage
                        width: parent.width
                        height: width
                        scale: 0.0
                        anchors.centerIn: parent
                        source: contact.avatar.imageUrl
                        engine: declarativeEngine
                    }
                }
                Text {
                    text: contact.displayLabel
                    color: "white"
                    font.pixelSize: 20
                    anchors.top:avatar.top
                    anchors.topMargin: 20
                }

                states: [
                     State {
                         name: "Show"; when: stationImage.imageStatus == RoundedImage.Ready
                         PropertyChanges { target: stationImage; scale: 1 }
                         PropertyChanges {target: defaultImage; visible: false}
                     }
                 ]
                 transitions: [
                     Transition {
                         NumberAnimation {
                             properties: "scale"; duration: 500; easing.type: Easing.InOutQuad
                         }

                     }
                 ]
            }

            MouseArea{
                anchors.fill: parent
                onClicked: {
                    context.sendSMS(contact.phoneNumber.number);
                    indicator.visible = false;
                    indicator.running = false;
                }
            }
        }
    }

    BusyIndicator {
        id: indicator
        anchors.centerIn: parent
        platformStyle: BusyIndicatorStyle { size: "large" }
        running: false
        visible: false
    }

    Item {
        id: playbackProgressBarArea
        width: parent.width
        height: playbackProgressBarAreaBg.sourceSize.height
        anchors.bottom: pageBottomBar.top
        visible: {
            if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                return true;
            } else {
                return false;
            }
        }
        Image {
            id: playbackProgressBarAreaBg
            source: "../image/music_play_bg.png"
        }
        MediaPlaybackProgressBar {
            id: mediaPlaybackProgressBar
            anchors.verticalCenter: parent.verticalCenter
            value: context.currentPlayingPosition
            maximum: context.currentPlayingDuration
            leftmum: maximum - value
        }
    }

    Image {
        id: pageTopBar
        width: parent.width
        anchors.top: parent.top
        source: "../image/top_bar.png"

        Text {
            anchors.left: parent.left
            anchors.leftMargin: 20
            anchors.verticalCenter: parent.verticalCenter
            font.pixelSize: 24
            color: "white"
            text: qsTr("Invite Addressbook Friends")
        }
    }

    StationsBottomBar {
        id: pageBottomBar
        anchors.bottom: parent.bottom
        onGoBack: {
            pageStack.pop();
        }
    }
}

