import QtQuick 1.0
import com.nokia.meego 1.0
import "CommonUtil.js" as Util

Item {
    id: artistInfoViewer
    width: parent.width
    height: parent.height

    property int gigCount: 0
    property string avatar: ""
    property string artistFacebookUrl: ""
    property string artistTwitterUrl: ""
    property string artistMyspaceUrl: ""
    property string artistWikiUrl: ""

    property bool concertStatus: false
    property bool mbStatus: false
    property bool discogsStatus: false

    property int otherSitesCount: 0


    Connections {
        target: context
        onGetConcertListingFinished: {
            concertStatus = true;

            if(type === 0){
                gigCount = eventCount;
                concertList.model=concertModel;
            }

            if(concertStatus && mbStatus && discogsStatus){
                indicator.running = false;
                indicator.visible = false;
            }
        }
        onGetMusicbrainzInfoFinished: {
            mbStatus = true;

            if(type === 0){
                artistFacebookUrl = facebookUrl;
                artistTwitterUrl = twitterUrl;
                artistMyspaceUrl = myspaceUrl;
                artistWikiUrl = wikiUrl;

                if(facebookUrl !== "")
                    facebookBt.enabled = true;

                if(twitterUrl !== "")
                    twifferBt.enabled = true;

                if(myspaceUrl !== "")
                    myspaceBt.enabled = true;

                if(wikiUrl !== "")
                    wikiBt.enabled = true;
            }

            if(concertStatus && mbStatus && discogsStatus){
                indicator.running = false;
                indicator.visible = false;
            }
        }
        onGetDiscogsInfoFinished: {
            discogsStatus = true;

            if(type === 0){
                avatar = artistAvatar;
                otherSitesCount = otherSiteCount;

                if(otherSiteCount !== 0)
                    otherSitesBt.enabled = true;

                if(photoCount !== 0)
                    galleryBt.enabled = true;
            }

            if(concertStatus && mbStatus && discogsStatus){
                indicator.running = false;
                indicator.visible = false;
            }
        }
    }

    Image {
        id: backgroudImg
        width: parent.width
        height: parent.height
        source: "../image/home_bg.png"
    }

    Item {
        id:artistPage
        width: parent.width
        height: 200
        anchors.top: pageTopBar.bottom
        anchors.left: parent.left

        Image {
            id: bgImg
            width: parent.width
            height: parent.height
            source: "../image/pop_up.png"
        }

        Item {
            id:artistPic
            width: 150
            height: width
            anchors.top: parent.top
            anchors.topMargin: 20
            anchors.left: parent.left
            anchors.leftMargin: 15


            Image {
                id: defaultImage
                width: parent.width
                height: width
                source: Util.getRandomDefaultThumb();
            }

            Image {
                id: artistImage
                width: parent.width
                height: width
                source: avatar
            }

            states: [
                State {
                    name: "Show"; when: artistImage.status == Image.Ready
                    PropertyChanges { target: artistImage; scale: 1 }
                    PropertyChanges {target: defaultImage; visible: false}
                }
            ]
            transitions: [
                Transition {
                    NumberAnimation {
                        properties: "scale"; duration: 500; easing.type: Easing.InOutQuad
                    }

                }
            ]
        }

        Grid {
            id:artistLink
            anchors.top: artistPic.top
            anchors.left: artistPic.right
            anchors.leftMargin: 30
            anchors.right: parent.right
            anchors.rightMargin: 20
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 20
            columns: 3
            rows: 2
            spacing: 20


            MyButton {
                id: facebookBt
                width: 70
                height: width
                anchors.leftMargin: 15
                enabled: false
                image: facebookBt.enabled? "../image/facebook_icon.png" : "../image/facebook_d.png"
                onClicked: {
                    //external link
                    context.openBrowerPage(artistFacebookUrl);
                }
            }

            MyButton {
                id: twifferBt
                width: 70
                height: width
                enabled: false
                image: twifferBt.enabled? "../image/twtter_icon.png" : "../image/twtter_d.png"
                onClicked: {
                    //external link
                    context.openBrowerPage(artistTwitterUrl);
                }
            }

            MyButton {
                id: myspaceBt
                width: 70
                height: width
                enabled: false
                image: myspaceBt.enabled? "../image/people_icon.png" : "../image/people_d.png"
                onClicked: {
                    //external link
                    context.openBrowerPage(artistMyspaceUrl);
                }
            }

            MyButton {
                id: wikiBt
                width: 70
                height: width
                enabled: false
                image: wikiBt.enabled? "../image/w_icon.png" : "../image/w_d.png"
                onClicked: {
                    //external link
                    context.openBrowerPage(artistWikiUrl);
                }
            }

            MyButton {
                id: otherSitesBt
                width: 70
                height: width
                enabled: false
                image: otherSitesBt.enabled? "../image/location_icon.png" : "../image/location_d.png"
                onClicked: {
                    //external link +other sites
                    otherSitesLabel.state = "ShowUp";
                }
            }

            MyButton {
                id: galleryBt
                width: 70
                height: width
                enabled: false
                image: galleryBt.enabled? "../image/photo_icon.png" : "../image/photo_d.png"
                onClicked: {
                    //external link +gallery
                    pageStack.push(Qt.resolvedUrl("ArtistGalleryVewer.qml"),
                                   {gridViewModel: artistThumbnailModel});
                }
            }

        }
    }

    Text {
        id: gigLabel
        anchors.top: artistPage.bottom
        anchors.topMargin: 15
        anchors.left: parent.left
        anchors.leftMargin: 25
        color: "white"
        font.pixelSize: 24
        font.bold: true
        text: "" + gigCount + qsTr(" gigs")
    }

    Image {
        id: separator
        height: 3
        anchors.top: gigLabel.bottom
        anchors.topMargin: 5
        anchors.left: parent.left
        anchors.leftMargin: 15
        anchors.right: parent.right
        anchors.rightMargin: 20
        source: "../image/play_line.png"
    }


    ListView {
        id:concertList
        anchors.top: separator.bottom
        anchors.bottom: pageBottomBar.top
        anchors.left: gigLabel.left
        anchors.right: parent.right
        clip: true

        delegate: Item {
            width: ListView.view.width
            height: 100

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    context.openBrowerPage(concertUri);
                }
            }

            Text {
                id: venueText
                anchors.top: parent.top
                anchors.topMargin: 10
                anchors.left: parent.left
                anchors.right: parent.right
                color: "white"
                font.pixelSize: 20
                text: venue
            }
            Text {
                id: startDateText
                anchors.top: venueText.bottom
                anchors.left: parent.left
                color: "lightGray"
                font.pixelSize: 20
                text: startDate
            }
            Text {
                id: cityText
                anchors.top: startDateText.bottom
                anchors.left: parent.left
                color: "lightGray"
                font.pixelSize: 20
                text: city
            }

        }
    }

    BusyIndicator {
        id: indicator
        anchors.centerIn: parent
        platformStyle: BusyIndicatorStyle { size: "large" }
        running: true
    }

    Item {
        id: playbackProgressBarArea
        width: parent.width
        height: playbackProgressBarAreaBg.sourceSize.height
        anchors.bottom: pageBottomBar.top
        visible: {
            if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                return true;
            } else {
                return false;
            }
        }
        Image {
            id: playbackProgressBarAreaBg
            source: "../image/music_play_bg.png"
        }
        MediaPlaybackProgressBar {
            id: mediaPlaybackProgressBar
            anchors.verticalCenter: parent.verticalCenter
            value: context.currentPlayingPosition
            maximum: context.currentPlayingDuration
            leftmum: maximum - value
        }
    }

    OtherSitesViewer {
        id:otherSitesLabel
        listViewModel: artistOtherSiteModel
        sitesCount: otherSitesCount
    }

    StationPlayerTopBar {
        id: pageTopBar
        anchors.top: parent.top
        stationNameText: context.currentSongArtist
    }

    StationsBottomBar {
        id: pageBottomBar
        anchors.bottom: parent.bottom

        onGoBack: {
            pageStack.pop();
        }
    }

    Component.onCompleted: {
        context.getArtistInfo();
    }
}
