import QtQuick 1.0
import com.nokia.meego 1.0
import "CommonUtil.js" as Util
import RoundedImage 1.0

Item {
    id: chatWithFriendPage
    property string userId
    property bool createChat: false
    property string objectId:""
    property bool haveChat: false

    width: parent.width
    height: parent.height

    Connections {
        target: context
        onRefreshMessageFinished: {
            messageList.model=messageModel;
            messageList.currentIndex=messageList.count-1;
            if(objectId!="0"){
                mask.visible = false;
                indicator.running = false;
                indicator.visible = false;
                if(chatWithFriendPage.createChat==false){
                    chatWithFriendPage.createChat = true;
                    chatWithFriendPage.objectId = createdObjectId;
                }
            }else{
                mask.visible = false;
                indicator.running = false;
                indicator.visible = false;
            }
        }
    }

    MouseArea {
        anchors.fill: parent
        onClicked: {
            messageInput.closeSoftwareInputPanel();
            messageInput.focus=false;
        }
    }

    Image {
        id: backgroudImg
        width: parent.width
        height: parent.height
        source: "../image/home_bg.png"
    }

    StationsTopBar {
        id: stationTopBar
        stationIconSource: "../image/inbox_b.png"
        stationNameText: qsTr("Message")
    }

    ListView {
        id: messageList
        width: parent.width
        anchors.top: stationTopBar.bottom
        anchors.bottom: inputArea.top
        anchors.topMargin: 10
        clip: true
        delegate: messageListDelegate

        MouseArea {
            anchors.fill: parent
            onClicked: {
                messageInput.closeSoftwareInputPanel();
                messageInput.focus=false;
            }
        }
    }

    Component {
        id: messageListDelegate
        Item {
            width: ListView.view.width
            height: (name.height + createTime.height + ownerComment.height) < 100 ? 100 : name.height + createTime.height + ownerComment.height
            Item {
                id: ownerIcon
                anchors.left: parent.left
                anchors.leftMargin: 10
                width: 90;
                height: width;
                smooth: true
                RoundedImage {
                    id: defaultImg
                    width: parent.width - 2
                    height: width
                    anchors.centerIn: parent
                    source: Util.getRandomDefaultThumb();
                    engine: declarativeEngine
                }
                RoundedImage {
                    id: image
                    visible: false
                    width: parent.width - 2
                    height: width
                    anchors.centerIn: parent
                    source: ownerImage
                    engine: declarativeEngine
                }
            }
            Text {
                id: name
                anchors.top: parent.top
                anchors.left: ownerIcon.right
                anchors.leftMargin: 10
                anchors.right: parent.right
                elide: Text.ElideRight
                color: "white"
                font.pixelSize: 20
                text: ownerName
            }
            Text {
                id: createTime
                anchors.left: name.left
                anchors.top: name.bottom
                color: "white"
                text: createTs
                font.pixelSize: 16
            }
            Text {
                id: ownerComment
                anchors.left: name.left
                anchors.right: parent.right
                anchors.top: createTime.bottom
                color: "white"
                wrapMode: Text.Wrap
                text: comment
                font.pixelSize: 16
            }
            states: [
                 State {
                     name: "Show"; when: image.imageStatus == RoundedImage.Ready
                     PropertyChanges { target: image; visible: true }
                     PropertyChanges {target: defaultImg; visible: false}
                 }
             ]
        }
    }

    Item {
        id: inputArea
        width: parent.width
        height: inputAreaBg.sourceSize.height
        anchors.bottom: {
            if (playbackProgressBarArea.visible == false) {
                return stationBottomBar.top;
            } else {
                return playbackProgressBarArea.top;
            }
        }
        Image {
            id: inputAreaBg
            anchors.fill: parent
            source: "../image/search_bg.png"
        }
        Image {
            id: inputBox
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.leftMargin: 10
            anchors.rightMargin: 10
            anchors.verticalCenter: parent.verticalCenter
            anchors.bottomMargin: 10
            source: "../image/search.png"
            TextInput {
                id: messageInput
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.rightMargin: 50
                anchors.leftMargin: 15
                anchors.verticalCenter: parent.verticalCenter
                font.pixelSize: 20
                color: "black"
                onActiveFocusChanged: {
                    if (messageInput.activeFocus) {
                        playbackProgressBarArea.visible = false;
                        stationBottomBar.visible = false;
                    } else if (!messageInput.activeFocus) {
                        if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                            playbackProgressBarArea.visible = true;
                        }
                        stationBottomBar.visible = true;
                    }
                }
            }
            Text {
                id: messageDefaultText
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.rightMargin: 50
                anchors.leftMargin: 15
                anchors.verticalCenter: parent.verticalCenter
                font.pixelSize: 20
                color: "gray"
                wrapMode: Text.Wrap
                elide: Text.ElideRight
                text: qsTr("Write message")
                visible: {
                    if (messageInput.text.length > 0 || messageInput.activeFocus) {
                        return false;
                    } else {
                        return true;
                    }
                }
            }
        }
        Image {
            id: icon
            anchors.right: parent.right
            anchors.rightMargin: 20
            anchors.verticalCenter: parent.verticalCenter
            source: "../image/message_icon.png"
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    mask.visible = true;
                    indicator.running = true;
                    indicator.visible = true;
                    messageInput.closeSoftwareInputPanel();
                    messageInput.focus=false;
                    if(chatWithFriendPage.createChat==false){
                        context.newChat(userId,messageInput.text);
                    }else{
                        context.replyToChat(chatWithFriendPage.objectId, messageInput.text);
                    }
                    messageInput.text = "";
                }
            }
        }
    }

    Rectangle{
        id:mask
        width: parent.width
        anchors.top:stationTopBar.bottom
        anchors.bottom: stationBottomBar.top
        color: "transparent"
        visible: false

        MouseArea{
            anchors.fill: parent
            onClicked: {}
        }
        BusyIndicator {
            id: indicator
            anchors.centerIn: parent
            platformStyle: BusyIndicatorStyle { size: "large" }
            running: false
            visible: false
        }
    }

    Item {
        id: playbackProgressBarArea
        width: parent.width
        height: playbackProgressBarAreaBg.sourceSize.height
        anchors.bottom: stationBottomBar.top
        visible: {
            if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                return true;
            } else {
                return false;
            }
        }
        Image {
            id: playbackProgressBarAreaBg
            source: "../image/music_play_bg.png"
        }
        MediaPlaybackProgressBar {
            id: mediaPlaybackProgressBar
            anchors.verticalCenter: parent.verticalCenter
            value: context.currentPlayingPosition
            maximum: context.currentPlayingDuration
            leftmum: maximum - value
        }
    }
    StationsBottomBar {
        id: stationBottomBar
        anchors.bottom: parent.bottom
        onVisibleChanged: {
            if (playbackProgressBarArea.visible == true) {
                if (stationBottomBar.visible == true) {;
                    inputArea.anchors.bottom = playbackProgressBarArea.top
                }
            } else if (playbackProgressBarArea.visible == false) {
                if (stationBottomBar.visible == true) {
                    inputArea.anchors.bottom = stationBottomBar.top;
                } else if (stationBottomBar.visible == false) {
                    inputArea.anchors.bottom = chatWithFriendPage.bottom;
                }
            }
        }

        onGoBack: {
            messageInput.closeSoftwareInputPanel();
            messageInput.focus=false;
            pageStack.pop();
        }
    }
}
