import QtQuick 1.0
import com.nokia.meego 1.0
import "CommonUtil.js" as Util

Item{
    id:editStationName
    width: parent.width
    height: parent.height

    property bool errorInfoStatus: false

    Connections {
        target: context
        onRenameStationFinished: {
            mask.visible = false;
            indicator.running = false;
            indicator.visible = false;
            if (type === 0) {
                pageStack.pop();
            }else if(type === 1){
                warningIcon.visible=true;
                errorInfo.text = qsTr("Rename failed. Please try again.");
                errorInfoStatus = true;
            }
        }
    }

    MouseArea{
        anchors.fill:parent
        onClicked: {
            stationsNameInput.closeSoftwareInputPanel();
        }
    }
    Image {
        id: topBarBg
        source: "../image/top_bar_b.png"
    }

    Rectangle{
        id:cancelBtn
        anchors.left: parent.left
        anchors.leftMargin: 30
        anchors.verticalCenter: topBarBg.verticalCenter
        width: cancelBtnBg.sourceSize.width
        height: cancelBtnBg.sourceSize.height
        color: "transparent"
        Image {
            id: cancelBtnBg
            source: "../image/cancel_b.png"
        }
        Text {
            text: qsTr("Cancel")
            font.bold: true
            font.pixelSize: 24
            anchors.centerIn: cancelBtnBg
        }
        MouseArea{
            anchors.fill:parent
            onClicked: {
                stationsNameInput.closeSoftwareInputPanel();
                pageStack.pop();
            }
        }
    }

    Rectangle{
        id:doneBtn
        anchors.right:parent.right
        anchors.rightMargin: 30
        anchors.verticalCenter: topBarBg.verticalCenter
        width: doneBtnBg.sourceSize.width
        height: doneBtnBg.sourceSize.height
        color: "transparent"
        Image {
            id: doneBtnBg
            source: "../image/cancel_a.png"
        }
        Text {
            text: qsTr("Done")
            font.bold: true
            font.pixelSize: 24
            color: "white"
            anchors.centerIn: doneBtnBg
        }
        MouseArea{
            anchors.fill: parent
            onClicked: {
                stationsNameInput.closeSoftwareInputPanel();
                if(stationsNameInput.text==""){
                    warningIcon.visible=true;
                    errorInfo.text=qsTr("Station's name can not be empty!");
                    errorInfoStatus = true;
                }else{
                    mask.visible = true;
                    indicator.running=true;
                    indicator.visible=true;
                    errorInfo.text="";
                    warningIcon.visible=false;
                    context.renameStation(context.currentPlayingStationId, Util.trim(stationsNameInput.text));
                }
            }
        }
    }
    Image {
        anchors.left: parent.left
        anchors.verticalCenter: stationsName.verticalCenter
        source: "../image/arrow.png"
    }
    Text {
        id: stationsName
        text: qsTr("Station's name:")
        color: "green"
        font.bold: true
        font.pixelSize: 24
        anchors.top: topBarBg.bottom
        anchors.topMargin: 30
        anchors.left: parent.left
        anchors.leftMargin: 20
    }

    SipAttributes{
        id:sipAttributes
        actionKeyLabel: "Done"
        actionKeyHighlighted: true
        actionKeyEnabled: true
    }

    TextArea{
        id:stationsNameInput
        anchors.top: stationsName.top
        anchors.topMargin: -15
        anchors.left: stationsName.right
        anchors.leftMargin: 10
        anchors.right: parent.right
        anchors.rightMargin: 10
        font.pixelSize: 24
        text: context.currentPlayingStationName
        style: TextAreaStyle {
            background: ""
            backgroundSelected: ""
            backgroundCornerMargin: 0
        }
        platformSipAttributes:sipAttributes;
        onTextChanged: {
            var len = text.length;
            for (var i = 0 ; i < len ; i++) {
                if (text.charAt(i) == '\n') {
                    stationsNameInput.closeSoftwareInputPanel();
                    stationsNameInput.text = Util.trim(text);
                    stationsNameInput.focus = false;
                    if(stationsNameInput.text==""){
                        warningIcon.visible=true;
                        errorInfo.text=qsTr("Station's name can not be empty!");
                        errorInfoStatus = true;
                    }else{
                        mask.visible = true;
                        indicator.running=true;
                        indicator.visible=true;
                        errorInfo.text="";
                        warningIcon.visible=false;
                        context.renameStation(context.currentPlayingStationId,stationsNameInput.text);
                    }
                }
            }
        }
    }

    Image {
        id: warningIcon
        source: "../image/warning.png"
        visible: false
        anchors.left: stationsName.left;
        anchors.top: stationsName.bottom
        anchors.topMargin: 20
    }
    Text {
        id: errorInfo
        anchors.left: warningIcon.right
        anchors.leftMargin: 10
        anchors.verticalCenter: warningIcon.verticalCenter
        wrapMode: Text.WrapAtWordBoundaryOrAnywhere
        color: "red"
        font.pixelSize: 24
    }

    Rectangle{
        id:mask
        width: parent.width
        height: parent.height
        color: "transparent"
        visible: false

        MouseArea{
            anchors.fill: parent
            onClicked: {}
        }
        BusyIndicator {
            id: indicator
            platformStyle: BusyIndicatorStyle { size: "large" }
            running: false
            visible: false
            anchors.centerIn: parent
        }
    }

    Timer{
        id: timer
        running: errorInfoStatus
        interval: 4000
        onTriggered: {
            warningIcon.visible=false;
            errorInfo.text=""
            errorInfoStatus=false;
        }
    }
}

