import QtQuick 1.0
import com.nokia.meego 1.0
import "CommonComponent" as CommonComponent

Rectangle{
    id: soundTrackerLoginPage
    width: parent.width
    height: parent.height

    property bool errorInfoStatus: false

    function isEmail(str){
           var reg = /^([a-zA-Z0-9_.-])+@([a-zA-Z0-9_-])+((\.[a-zA-Z0-9_-]{2,3}){1,2})$/;
           return reg.test(str);
    }
    Connections {
        target: context
        onForgotPasswordFinished:{
            mask.visible = false;
            indicator.running = false;
            indicator.visible = false;
            if(type===0){
                resetPasswordDialog.open();
            }else if(type==1){
                warningIcon.visible=true;
                errorInfo.text = qsTr("Send Email failed. Please try again.");
                errorInfoStatus = true;
            }else if(type==2){
                warningIcon.visible=true;
                errorInfo.text = qsTr("Unknown Email. Please check this and try again.");
                errorInfoStatus = true;
            }
        }
    }

    MouseArea{
        anchors.fill:parent
        onClicked: {
            accountInput.closeSoftwareInputPanel();
        }
    }
    Image {
        id: bg
        source: "../image/home_bg.png"
        width: parent.width
        height:parent.height
    }

    CommonComponent.CancelDoneTopBar{
        id:topBar
        cancelText:qsTr("Cancel")
        doneText:qsTr("Reset")
        onCancel: {
            accountInput.closeSoftwareInputPanel();
            pageStack.pop();
        }
        onDone: {
            accountInput.closeSoftwareInputPanel();
            if(accountInput.text==""){
                warningIcon.visible=true;
                errorInfo.text=qsTr("Email Address can not be empty!");
                errorInfoStatus = true;
            }else if(!isEmail(accountInput.text)){
                warningIcon.visible=true;
                errorInfo.text=qsTr("Please enter a valid Email Address!");
                errorInfoStatus = true;
            }else{
                mask.visible = true;
                indicator.running=true;
                indicator.visible=true;
                errorInfo.text="";
                warningIcon.visible=false;
                context.forgotPassword(accountInput.text);
            }
        }
    }

    Text {
        id: forgetPassword
        text: qsTr("Forgot password")
        anchors.top:topBar.bottom
        anchors.topMargin: 10
        anchors.left:parent.left
        anchors.leftMargin: 20
        color: "white"
        font.bold: true
        font.pixelSize: 30
    }
    Text {
        id: emailTag
        text: qsTr("Email address")
        color: "gray"
        font.bold: true
        font.pixelSize: 24
        anchors.top: forgetPassword.bottom
        anchors.topMargin: 10
        anchors.left: forgetPassword.left
    }
    Image {
        id: accountInputBg
        source: "../image/search.png"
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top:emailTag.bottom
    }
    TextInput{
        id:accountInput
        anchors.verticalCenter: accountInputBg.verticalCenter
        anchors.left: accountInputBg.left
        anchors.leftMargin: 10
        anchors.right: accountInputBg.right
        anchors.rightMargin: 10
        font.pixelSize: 24
    }
    Text {
        id: tipsInfo
        text: qsTr("Would you like us to send you an email with instructions to reset your password?")
        color: "gray"
        font.bold: true
        font.pixelSize: 24
        anchors.top: accountInputBg.bottom
        anchors.topMargin: 10
        anchors.left: forgetPassword.left
        width: parent.width-40
        wrapMode: Text.WrapAtWordBoundaryOrAnywhere
    }

    Image {
        id: warningIcon
        source: "../image/warning.png"
        visible: false
        anchors.left: forgetPassword.left;
        anchors.top: tipsInfo.bottom
        anchors.topMargin: 10
    }
    Text {
        id: errorInfo
        anchors.left: warningIcon.right
        anchors.leftMargin: 10
        anchors.top: warningIcon.top
        wrapMode: Text.WrapAtWordBoundaryOrAnywhere
        width: parent.width-50
        color: "red"
        font.pixelSize: 24
    }

    Rectangle{
        id:mask
        width: parent.width
        height: parent.height
        color: "transparent"
        visible: false

        MouseArea{
            anchors.fill: parent
            onClicked: {}
        }
        BusyIndicator {
            id: indicator
            platformStyle: BusyIndicatorStyle { size: "large" }
            running: false
            visible: false
            anchors.centerIn: parent
        }
    }

    Timer{
        id: timer
        running: errorInfoStatus
        interval: 4000
        onTriggered: {
            warningIcon.visible=false;
            errorInfo.text=""
            errorInfoStatus=false;
        }
    }
    StationPlayerPopDialog {
        id: resetPasswordDialog
        dialogAccept: qsTr("Ok")
        dialogTitle: qsTr("Forgot password")
        dialogContent: qsTr("We have sent you an email with instructions to reset your password.")
    }
}

