import QtQuick 1.0
import "CommonUtil.js" as Util
import com.nokia.meego 1.0
import RoundedImage 1.0

Item {
    id: showFriendsByList
    property alias listViewModel: listView.model
    width: parent.width
    height: parent.height

    property bool needPressButton: false
    signal itemClick(int index,string id,string name,string location,
                     string pictureUrl,string numFollowers,string numFollowing
                     ,string email,string accountExistent)
    ListView {
        id: listView
        width: parent.width
        height: parent.height
        clip: true
        delegate: listViewDelegate
    }
    Component {
        id: listViewDelegate
        Item {
            width: ListView.view.width
            height: 100
            Item {
                id: stationIcon
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.verticalCenter: parent.verticalCenter
                width: 90;
                height: width;
                smooth: true
                RoundedImage {
                    id: defaultImg
                    width: parent.width - 2
                    height: width
                    anchors.centerIn: parent
                    source: Util.getRandomDefaultThumb();
                    engine: declarativeEngine
                }
                RoundedImage {
                    id: friendsImage
                    visible: false
                    width: parent.width - 2
                    height: width
                    anchors.centerIn: parent
                    source: pictureUrl
                    engine: declarativeEngine
                }
            }
            Text {
                id: friendsName
                anchors.top: stationIcon.top
                anchors.topMargin: 10
                anchors.left: stationIcon.right
                anchors.leftMargin: 20
                anchors.right: parent.right
                elide: Text.ElideRight
                color: "white"
                font.pixelSize: 20
                text: friendName
            }
            Text {
                id: recentArtistName
                anchors.top: friendsName.bottom
                anchors.topMargin: 10
                anchors.left: stationIcon.right
                anchors.leftMargin: 20
                anchors.right: parent.right
                elide: Text.ElideRight
                color: "white"
                font.pixelSize: 16
                text: {
                    if(recentArtists === "") return "";
                    else return qsTr("Recent artists: ") + recentArtists;
                }
            }
            MouseArea{
                anchors.fill: parent
                onClicked: {
                    itemClick(index,friendId,friendName,location,
                              pictureUrl,numFollowers,numFollowing,
                              email,accountExistent);
                }
            }
	    
            states: [
                 State {
                     name: "Show"; when: friendsImage.imageStatus == RoundedImage.Ready
                     PropertyChanges { target: friendsImage; visible: true }
                     PropertyChanges {target: defaultImg; visible: false}
                 }
             ]
	     
            Binding {
                 target: pressButton; property: 'visible'
                 value: needPressButton
             }
	     
             transitions: [
                 Transition {
                     NumberAnimation {
                         properties: "scale"; duration: 500; easing.type: Easing.InOutQuad
                     }
                 }
             ]
             Image {
                 id: pressButton
                 anchors.right: parent.right
                 anchors.rightMargin: 10
                 anchors.verticalCenter: parent.verticalCenter
                 source: "../image/arrow_b.png"

//                 MouseArea{
//                     anchors.fill: parent
//                     onClicked: {
//                         if(needPressButton)
//                         {
//                             itemClick(index,friendId,friendName,location,
//                             pictureUrl,email,accountExistent);
//                         }
//                     }
//                 }
                 visible:false
             }
        }
    }
}
