import QtQuick 1.0
import com.nokia.meego 1.0

Rectangle {
    id: friendsStationListView
    width: parent.width
    height: parent.height

    property int selcetedItem: 1
    property string userId: ""
    property alias friendsList: friendsList
    property alias friendsFollowingList: friendsFollowingList
    property alias friendsBottomBar: friendsBottomBar
    property string headerBarText: qsTr("Friends' Stations")
    property int suggestedFriendsNumber: 0

    Connections {
        target: context
        onGetFollowersFinished: {
            mask.visible=false;
            indicator.running = false;
            indicator.visible = false;
            friendsList.listViewModel = followersModel;
        }
        onGetFollowingFinished:{
            mask.visible=false;
            indicator.running = false;
            indicator.visible = false;
            friendsFollowingList.listViewModel = followingModel;
        }
    }

    MouseArea{
        anchors.fill: parent
        onClicked: {
            friendSearchBox.searchInput.closeSoftwareInputPanel();
            friendSearchBox.searchInput.focus=false;
        }
    }

    Image {
        id: backgroudImg
        width: parent.width
        height: parent.height
        source: "../image/home_bg.png"
    }

    StationsTopBar {
        id: stationTopBar
        stationIconSource: "../image/friend_station_b.png"
        stationNameText: headerBarText
    }

    // friendSearchBox
    FriendSearchBox {
        id: friendSearchBox
        anchors.top: stationTopBar.bottom
        visible: userId == "" ? true : false
    }

    // followerBtn
    Image {
        id: followerBtn
        anchors.top:friendSearchBox.visible?friendSearchBox.bottom:stationTopBar.bottom
        anchors.topMargin: friendSearchBox.visible?2:20
        anchors.right: parent.right
        anchors.rightMargin: parent.width/2

        Text {
            id: followers
            text: qsTr("Followers")
            anchors.centerIn: parent
            color: "white"
            font.bold: true
            font.pixelSize: 20
        }
        MouseArea{
            anchors.fill: parent
            onClicked: {
                followerBtn.source="../image/select_a01.png"
                followeringBtn.source = "../image/select_a02.png"
                friendSearchBox.searchInput.closeSoftwareInputPanel();
                friendSearchBox.searchInput.focus=false;
                if(selcetedItem==2){
                    friendsList.visible=true;
                    friendsFollowingList.visible=false;
                    mask.visible=true;
                    indicator.running = true;
                    indicator.visible = true;
                    context.getFollowers(userId);
                    selcetedItem=1;
                }
            }
        }
    }

    // followeringBtn
    Image {
        id: followeringBtn
        anchors.top:followerBtn.top
        anchors.left: followerBtn.right

        Text {
            id: followering
            text: qsTr("Following")
            anchors.centerIn: parent
            color: "white"
            font.bold: true
            font.pixelSize: 20
        }
        MouseArea{
            anchors.fill: parent
            onClicked: {
                followerBtn.source="../image/select_b01.png";
                followeringBtn.source = "../image/select_b02.png";
                friendSearchBox.searchInput.closeSoftwareInputPanel();
                friendSearchBox.searchInput.focus=false;
                if(selcetedItem==1){
                    friendsList.visible=false;
                    friendsFollowingList.visible=true;
                    mask.visible=true;
                    indicator.running = true;
                    indicator.visible = true;
                    context.getFollowing(userId);
                    selcetedItem=2;
                }
            }
        }
    }

    FriendsList {
        id: friendsList
        anchors.top: followerBtn.bottom
        anchors.bottom:bottomBar.visible?bottomBar.top:friendsBottomBar.visible?friendsBottomBar.top:parent.bottom
        anchors.topMargin: 10
        anchors.bottomMargin: 10
        onItemClick: {
            friendSearchBox.searchInput.closeSoftwareInputPanel();
            friendSearchBox.searchInput.focus=false;
            pageStack.push(Qt.resolvedUrl("SpecifyFriendStations.qml"),
                           {friendName:name,friendId:id,friendLocation:location,friendPhoto:pictureUrl,followersNum:numFollowers,followingNum:numFollowing});
        }
    }

    FriendsList {
        id: friendsFollowingList
        anchors.top: followerBtn.bottom
        anchors.bottom: bottomBar.visible?bottomBar.top:friendsBottomBar.visible?friendsBottomBar.top:parent.bottom
        anchors.topMargin: 10
        anchors.bottomMargin: 10
        visible:false
        onItemClick: {
            friendSearchBox.searchInput.closeSoftwareInputPanel();
            friendSearchBox.searchInput.focus=false;
            pageStack.push(Qt.resolvedUrl("SpecifyFriendStations.qml"),
                           {friendName:name,friendId:id,friendLocation:location,friendPhoto:pictureUrl,followersNum:numFollowers,followingNum:numFollowing});
        }
    }

    StationsBottomBar {
        id: bottomBar
        anchors.bottom: parent.bottom
        visible: userId==""?false:true
        onGoBack: {
            pageStack.pop();
        }
    }

    FriendsBottomBar {
        id: friendsBottomBar
        anchors.bottom: parent.bottom
        visible: userId==""?true:false
        strText: qsTr("Add friends")
        strViewFirstItem:qsTr("Add friends")
        strViewSecondItem:qsTr("Open player")

        onGoBack: {
            pageStack.pop();
            userId = "";
        }

        onViewMenuItemClick: {
            switch(index)
            {
            case 0:
                pageStack.push(Qt.resolvedUrl("InviteFriends.qml"),{friendsNumber:suggestedFriendsNumber});
                break;
            case 1:
                pageStack.push(Qt.resolvedUrl("StationPlayer.qml"));
                break;
            }
        }

        onButtonClick: {
            pageStack.push(Qt.resolvedUrl("InviteFriends.qml"),{friendsNumber:suggestedFriendsNumber});
        }
    }

    // mask
    Rectangle {
        id: mask
        width: parent.width
        anchors.top: stationTopBar.bottom
        anchors.bottom: bottomBar.visible?bottomBar.top:friendsBottomBar.top
        color: "transparent"

        MouseArea {
            anchors.fill: parent
            onClicked: {}
        }
        BusyIndicator {
            id: indicator
            anchors.centerIn: parent
            platformStyle: BusyIndicatorStyle { size: "large" }
            running: true
        }
    }

    Component.onCompleted: {
        friendSearchBox.belongto="";
        if(selcetedItem==1){
            followerBtn.source="../image/select_a01.png"
            followeringBtn.source = "../image/select_a02.png"
            friendsList.visible = true;
            friendsFollowingList.visible = false;
            context.getFollowers(userId);
        }else if(selcetedItem==2){
            followerBtn.source="../image/select_b01.png";
            followeringBtn.source = "../image/select_b02.png";
            friendsList.visible = false;
            friendsFollowingList.visible = true;
            context.getFollowing(userId);
        }
    }
}
