import QtQuick 1.0
import com.nokia.meego 1.0
import "CommonUtil.js" as Util
import RoundedImage 1.0

Item {
    id: inboxPage
    width: parent.width
    height: parent.height

    Connections {
        target: context
        onGetInboxFinished: {
            indicator.running = false;
            indicator.visible = false;
            if (type === 0) {
                inboxList.model = inboxModel;
            }
        }
    }

    Image {
        id: backgroudImg
        width: parent.width
        height: parent.height
        source: "../image/home_bg.png"
    }

    StationsTopBar {
        id: stationTopBar
        stationIconSource: "../image/inbox_b.png"
        stationNameText: qsTr("Inbox")
    }

    ListView {
        id: inboxList
        width: parent.width
        anchors.top: stationTopBar.bottom
        anchors.bottom: stationBottomBar.top
        anchors.topMargin: 10
        anchors.bottomMargin: 10
        clip: true
        spacing: 15
//        model: inboxModel
        delegate: inboxListDelegate
    }
    Component {
        id: inboxListDelegate
        Item {
            width: ListView.view.width
            height: 100
            Item {
                id: ownerIcon
                anchors.left: parent.left
                anchors.leftMargin: 15
                width: 100;
                height: width
                RoundedImage {
                    id: defaultImg
                    width: parent.width - 2
                    height: width
                    anchors.centerIn: parent
                    source: Util.getRandomDefaultThumb();
                    engine: declarativeEngine
                }
                RoundedImage {
                    id: image
                    visible: false
                    width: parent.width - 2
                    height: width
                    anchors.centerIn: parent
                    source: ownerImage
                    engine: declarativeEngine
                }
            }
            Text {
                id: name
                anchors.top: parent.top
                anchors.left: ownerIcon.right
                anchors.leftMargin: 15
                anchors.right: parent.right
                elide: Text.ElideRight
                color: "white"
                font.pixelSize: 20
                text: ownerName
            }
            Text {
                id: createTime
                anchors.left: ownerIcon.right
                anchors.leftMargin: 15
                anchors.top: name.bottom
                color: "white"
                font.pixelSize: 16
                text: createTs
            }
            Text {
                id: ownerComment
                anchors.left: ownerIcon.right
                anchors.leftMargin: 15
                anchors.right: parent.right
                anchors.top: createTime.bottom
                color: "white"
                elide: Text.ElideRight
                wrapMode: Text.WordWrap
                font.pixelSize: 16
                text: comment
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if (read == "false") {
                        context.markComment(id, type);
                    }
                    if (type == "chat") {
                        pageStack.push(Qt.resolvedUrl("MessagePage.qml"), {objectId: objectId});
                    } else if (type == "station") {
                        pageStack.push(Qt.resolvedUrl("CommentsPage.qml"), {objectId: objectId});
                    } else if (type == "sharedstation") {
                        context.openSharedStation(objectId);
                        pageStack.push(Qt.resolvedUrl("StationPlayer.qml"));
                    }
                }
            }

            states: [
                 State {
                     name: "Show"; when: image.imageStatus == RoundedImage.Ready
                     PropertyChanges { target: image; visible: true }
                     PropertyChanges {target: defaultImg; visible: false}
                 }
             ]
//             transitions: [
//                 Transition {
//                     NumberAnimation {
//                         properties: "scale"; duration: 500; easing.type: Easing.InOutQuad
//                     }

//                 }
//             ]
        }
    }

    BusyIndicator {
        id: indicator
        anchors.centerIn: inboxList
        platformStyle: BusyIndicatorStyle { size: "large" }
        running: true
    }

    StationsBottomBar {
        id: stationBottomBar
        anchors.bottom: parent.bottom

        onGoBack: {
            pageStack.pop();
        }
    }
    Item {
        id: playbackProgressBarArea
        width: parent.width
        height: playbackProgressBarAreaBg.sourceSize.height
        anchors.bottom: stationBottomBar.top
        visible: {
            if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                return true;
            } else {
                return false;
            }
        }
        Image {
            id: playbackProgressBarAreaBg
            source: "../image/music_play_bg.png"
        }
        MediaPlaybackProgressBar {
            id: mediaPlaybackProgressBar
            anchors.verticalCenter: parent.verticalCenter
            value: context.currentPlayingPosition
            maximum: context.currentPlayingDuration
            leftmum: maximum - value
        }
    }
    Component.onCompleted: {
        context.getInbox();
    }
}
