import QtQuick 1.0
import com.nokia.meego 1.0

Rectangle {
    width: parent.width
    height: parent.height
    id:inviteFriends
    property string email: ""
    property string password: ""
    property variant friendsList
    property string topBarCaption: ""

    property string emailBodyContent: qsTr("send invitation to your friends")
    property string emailSubjectContent: qsTr("SoundTracker Invitation")

    property bool startInput: false

    property bool emailEnabled:true
    Image {
        id: bg
        source:  "../image/home_bg.png"
    }
    MouseArea{
        anchors.fill: parent
        onClicked: {
            searchInput.closeSoftwareInputPanel();
            searchInput.focus = false;
        }
    }

    // stationTopBar
    StationsTopBar {
        id: stationTopBar
        stationNameText: qsTr("Invite ")+topBarCaption+qsTr(" Friends")
    }

    // stationBottomBar
    StationsBottomBar {
        id: stationBottomBar
        anchors.bottom: parent.bottom
        onGoBack: {
            pageStack.pop();
            searchInput.closeSoftwareInputPanel();
        }
    }

    // searchArea
    Item {
        id: searchArea
        anchors.top: stationTopBar.bottom
        width: parent.width
        height: searchAreaBg.sourceSize.height
        Image {
            id: searchAreaBg
            anchors.fill: parent
            source: "../image/search_bg.png"
        }
        Image {
            id: searchBox
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.leftMargin: 10
            anchors.rightMargin: 10
            anchors.verticalCenter: parent.verticalCenter
            anchors.bottomMargin: 10
            source: "../image/search.png"

            Text {
                id: searchedDefaultText
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.rightMargin: 50
                anchors.leftMargin: 30
                anchors.verticalCenter: parent.verticalCenter
                font.pixelSize: 20
                color: "gray"
                wrapMode: Text.Wrap
                elide: Text.ElideRight
                text: qsTr("Search for ")+topBarCaption+qsTr(" friends")
                visible:
                {
                    if(searchInput.focus)
                    {
                        return false;
                    }
                    else
                    {
                        if(searchInput.text==="")
                        {
                            searchInput.closeSoftwareInputPanel();
                            return true;
                        }
                        else
                        {
                            return false;
                        }
                    }
                }
            }

            TextInput
            {
                id:searchInput
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.leftMargin: 30
                anchors.rightMargin: 50
                anchors.verticalCenter: parent.verticalCenter
                font.pixelSize: 20
                text: ""
                color: "black"
                onTextChanged: {
                    if(text==="")
                    {
                        if(focus)
                        {
                            indicator.running = true;
                            indicator.visible = true;
                            focus=false;
                            timer.restart();
                        }
                        else
                        {
                            indicator.running = true;
                            indicator.visible = true;
                            timer.restart();
                        }
                    }
                    if(startInput)
                    {
                        indicator.running = true;
                        indicator.visible = true;
                        if(timer.running == false)
                            timer.start();
                        else{
                            timer.restart();
                        }
                    }
                }
                onFocusChanged:
                {
                    startInput=focus;
                }
                onActiveFocusChanged: {
                    if (activeFocus) {
                        stationBottomBar.visible = false;
                    } else{
                        stationBottomBar.visible = true;
                    }
                }
            }
        }
        Image {
            id: icon
            anchors.right: parent.right
            anchors.rightMargin: 20
            anchors.verticalCenter: parent.verticalCenter
            source: "../image/icon_b.png"
            MouseArea{
                anchors.fill: parent
                onClicked: {
                    searchInput.text="";
                }
            }
        }
    }

    // friendsListView
    FriendsList{
        id: friendsListView
        anchors.top: searchArea.bottom
        anchors.bottom: {
            if(stationBottomBar.visible) {
                return stationBottomBar.top;
            }else {
                return inviteFriends.bottom;
            }
        }
        anchors.topMargin: 10
        anchors.bottomMargin: 10
        needPressButton: true
        onItemClick: {
            if(accountExistent==="true")
            {
                searchInput.closeSoftwareInputPanel();
                searchInput.focus=false;
                //add friend,then remove it from list view
                if(searchInput.text===""||searchInput.text===searchedDefaultText.text)
                {
                    context.addFriend("emailFriendsModel",index,"searchedFriendsModel");
                    //friendsListView.listViewModel=emailFriendsModel;
                }
                else
                {
                    context.addFriend("searchedFriendsModel",index,"emailFriendsModel");
                    //friendsListView.listViewModel=searchedFriendsModel;
                }
            }
            else
            {
                if(emailEnabled)
                {
                    Qt.openUrlExternally("mailto:"+email+"?body=" + emailBodyContent+"&subject="+emailSubjectContent);
                    emailEnabled=false;
                    emailOpenTimer.restart();
                }
            }
        }
    }

    Connections{
        target: context

        onGetEmailFriendsInfoFinished: {
            indicator.running = false;
            indicator.visible = false;
            if(type===0)
            {
                friendsListView.listViewModel=emailFriendsModel;
            }
            else
            {
                error.text=errorInfo;
                error.visible=true;
            }
        }
        onAddFriendFinished: {
            if(type===1)
            {
                errorDialog.dialogContent=errorInfo;
                errorDialog.open();
            }
            else
            {
                if(searchInput.text===""||searchInput.text===searchedDefaultText.text)
                {
                    friendsListView.listViewModel=emailFriendsModel;
                }
                else
                {
                    friendsListView.listViewModel=searchedFriendsModel;
                }
            }
        }

        onSearchFriendsFinished: {
            indicator.running = false;
            indicator.visible = false;
            if(searchInput.text===""||searchInput.text===searchedDefaultText.text)
            {
                friendsListView.listViewModel=emailFriendsModel;
            }
            else
            {
                friendsListView.listViewModel=searchedFriendsModel;
            }
        }
    }

    Text {
        id: error
        text: ""
        visible:false
        anchors.centerIn: parent
        color:"white"
        wrapMode: Text.WrapAnywhere
        font.pixelSize: 30
        font.bold: true
    }

    // indicator
    BusyIndicator {
        id: indicator
        anchors.centerIn: friendsListView
        platformStyle: BusyIndicatorStyle { size: "large" }
        running: true
    }

    Timer {
        id: timer
        interval: 700
        repeat: false
        running: false
        onTriggered: {
            context.searchFriends(searchInput.text);
        }
    }

    Timer {
        id: emailOpenTimer
        interval: 3000
        repeat: false
        running: false
        onTriggered: {
            emailEnabled=true;
        }
    }

    Item {
        id: playbackProgressBarArea
        width: parent.width
        height: playbackProgressBarAreaBg.sourceSize.height
        anchors.bottom: stationBottomBar.top
        visible: {
            if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                if(searchInput.activeFocus)
                {
                    return false;
                }
                else
                {
                    return true;
                }
            } else {
                return false;
            }
        }
        Image {
            id: playbackProgressBarAreaBg
            source: "../image/music_play_bg.png"
        }
        MediaPlaybackProgressBar {
            id: mediaPlaybackProgressBar
            anchors.verticalCenter: parent.verticalCenter
            value: context.currentPlayingPosition
            maximum: context.currentPlayingDuration
            leftmum: maximum - value
        }
    }

    StationPlayerPopDialog {
        id: errorDialog
        dialogAccept: qsTr("Ok")
        dialogTitle: qsTr("Error")
        //dialogContent: qsTr("This song has been added to favorite list")
    }


    Component.onCompleted:
    {
        context.findFriendsFromMailbox(email,password);
    }
}
