import QtQuick 1.1
import QtMobility.location 1.2

Item {
    id: page
    focus: true

    width: locationBb.sourceSize.width
    height: locationBb.sourceSize.height
    anchors.centerIn: locationBb
    anchors.margins: 5
    anchors.top: stationTopBar.bottom
    property bool loadOver: false

    PositionSource {
        id: myPositionSource
        active: true
        updateInterval: 2000
        onPositionChanged: {
            map.center = position.coordinate;
            page.loadOver = true;
            context.getNearbyStation(myPositionSource.position.coordinate.latitude,
                                     myPositionSource.position.coordinate.longitude);
            myPositionSource.stop();
        }
    }

    LandmarkBoxFilter {
        id: boxFilter
        topLeft: map.toCoordinate(Qt.point(0,0))
        bottomRight: map.toCoordinate(Qt.point(map.width, map.height))
    }

    LandmarkProximityFilter {
        id: proximityFilter
        center: myPositionSource.position.coordinate
        radius: 500000
    }

    LandmarkModel {
        id: landmarkModelAll
        autoUpdate: true
        filter: boxFilter
        limit: 20
    }

    LandmarkModel {
        id: landmarkModelNear
        autoUpdate: true
        filter: proximityFilter
        limit: 20
    }

    LandmarkCategoryModel {
        id: landmarkCategoryModel
        autoUpdate: true
    }

    Rectangle {
        id: dataArea
        anchors.fill: parent
        color: "#343434"
        Image { source: "../image/stripes.png"; fillMode: Image.Tile; anchors.fill: parent; opacity: 0.3 }

        Map {
            id: map
            plugin : Plugin { name : "nokia"}
            //![Map Plugin]
            anchors.fill: parent
            size.width: parent.width
            size.height: parent.height
            zoomLevel:15

            MapImage {
                source: "../image/mylocation.png"
                coordinate: myPositionSource.position.coordinate
            }

            MapObjectView {
                id: allLandmarks
                model: landmarkModelAll
                delegate: Component {
                    //![MapImage]
                    MapImage {
                        source:  "qrc:/images/location/landmarkstar.png"
                        coordinate: landmark.coordinate
                    }
                }
            }

            MapObjectView {
                id: landmarksNearMe
                model: landmarkModelNear
                delegate: Component {
                    MapGroup {
                        MapCircle {
                            color: "green"
                            radius: 100
                            center: landmark.coordinate
                        }
                        MapCircle {
                            color: "red"
                            radius: 30
                            center: landmark.coordinate
                        }
                    }
                }
            }
        }
    } // dataArea
}
