import QtQuick 1.0
import com.nokia.meego 1.0
import com.custom.errorinfo 1.0

Rectangle {
    id:lyricsRect
    width: parent.width
    height: parent.height
    Image {
        id: bg
        source:  "../image/home_bg.png"
    }
    property string lyricText: ""

    QtObject {
        id: errorAttributes
        property string errorFromNetwork:qsTr("Can not connect to server")
        property string errorFromNoLyric:qsTr("Can't find lyric")
    }

    function updateLyricView() {
        if(context.currentLyric===errorAttributes.errorFromNoLyric)
        {
            error.visible=true;
            error.text=context.currentLyric;
            indicator.running=false;
            indicator.visible=false;
        }
        else
        {
            error.visible=false;
            indicator.running=true;
            indicator.visible=true;
            context.trackIDfromMusixmatch(context.currentSongArtist,context.currentSongName);
        }
    }

    Connections {
        target: context
        onProcessLyricFinished: {
            if(0===type)
            {
                error.visible=false;
                context.currentLyric=lyric;
                lyricText=lyric;
            }
            else
            {
                error.visible=true;
                if(errorType===errorInfo.ECommonError)
                {
                    error.text=errorAttributes.errorFromNetwork;
                    context.currentLyric=errorAttributes.errorFromNetwork;
                }
                else if(errorType===errorInfo.ELyricNoFound)
                {
                    error.text=errorAttributes.errorFromNoLyric;
                    context.currentLyric=errorAttributes.errorFromNetwork;
                }
            }
            indicator.running=false;
            indicator.visible=false;

        }
        onProcessTrackIDFinished:
        {
            if(0===type)
            {
                error.visible=false;
                context.getLyric(trackID);
            }
            else
            {
                error.visible=true;
                if(errorType===errorInfo.ECommonError)
                {
                    error.text=errorAttributes.errorFromNetwork;
                    context.currentLyric=errorAttributes.errorFromNetwork;
                }
                else if(errorType===errorInfo.ELyricNoFound)
                {
                    error.text=errorAttributes.errorFromNoLyric;
                    context.currentLyric=errorAttributes.errorFromNetwork;
                }
                indicator.running=false;
                indicator.visible=false;
            }
        }
        onCurrentSongNameChanged:
        {
            indicator.running=true;
            indicator.visible=true;
            context.trackIDfromMusixmatch(context.currentSongArtist,context.currentSongName);
        }

    }

    Flickable
    {
        id:lyricFlick
        anchors.top: stationTopBar.bottom
        anchors.bottom: stationBottomBar.top
        anchors.left: parent.left
        anchors.leftMargin: 20
        width:parent.width-40
        contentWidth:text.width
        contentHeight: text.height
        flickableDirection:Flickable.VerticalFlick
        Text {
            id:text
            width: lyricsRect.width-40
            text:lyricText
            color:"white"
            font.pixelSize: 20
            wrapMode:Text.WrapAnywhere
        }
    }

    Item {
        id: playbackProgressBarArea
        width: parent.width
        height: playbackProgressBarAreaBg.sourceSize.height
        anchors.bottom: stationBottomBar.top
        visible: {
            if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                return true;
            } else {
                return false;
            }
        }
        Image {
            id: playbackProgressBarAreaBg
            source: "../image/music_play_bg.png"
        }
        MediaPlaybackProgressBar {
            id: mediaPlaybackProgressBar
            anchors.verticalCenter: parent.verticalCenter
            value: context.currentPlayingPosition
            maximum: context.currentPlayingDuration
            leftmum: maximum - value
        }
    }

    // indicator
    BusyIndicator {
        id: indicator
        anchors.centerIn: parent
        platformStyle: BusyIndicatorStyle { size: "large" }
        running: true
    }

    Text {
        id:error
        anchors.centerIn: parent
        text:""
        color:"white"
        font.pixelSize: 30
        wrapMode:Text.WrapAnywhere
        visible: false
    }

    // stationTopBar
    StationsTopBar {
        id: stationTopBar
        stationNameText: qsTr("Lyrics for") + " \"" + context.currentSongName + "\""
    }

    StationsBottomBar {
        id: stationBottomBar
        anchors.bottom: parent.bottom
        onGoBack: {
            pageStack.pop();
        }
    }

    Component.onCompleted: updateLyricView();
}
