import QtQuick 1.0
import com.nokia.meego 1.0
import "CommonUtil.js" as Util

Rectangle {
    id: myFavoritesPage
    width: parent.width
    height: parent.height

    property bool editing: false

    Image {
        id: bg
        source:  "../image/home_bg.png"
    }

    StationsTopBar {
        id: stationTopBar
        stationNameText: qsTr("Favorites")
    }

    // favoritesDelegate
    Component {
        id: favoritesDelegate
        Rectangle {
            width: favoritesView.width
            height: 100
            color: selected
                   ? "steelblue"
                   : "transparent"

            Image {
                id: defaultImg
                anchors.left: parent.left
                anchors.top: parent.top
                width: parent.height
                height: parent.height
                source: Util.getRandomDefaultThumb();
                //visible:true
            }
            Image {
                id: ownerImg
                anchors.left: parent.left
                anchors.top: parent.top
                width: parent.height
                height: parent.height
                source: albumUrl
                scale:0.0
                //source: "../image/arrow_b.png"
                //visible:false
            }
            states: [
                 State {
                     name: "Show"; when: ownerImg.status == Image.Ready
                     PropertyChanges { target: ownerImg; scale: 1.0 }
                     PropertyChanges {target: defaultImg; visible: false}
                 }
             ]
            transitions: [
                Transition {
                    NumberAnimation {
                        properties: "scale"; duration: 500; easing.type: Easing.InOutQuad
                    }
                }
            ]
            Text {
                id: songName
                anchors.left: ownerImg.right
                anchors.leftMargin: 10
                anchors.top: ownerImg.top
                anchors.topMargin: 10
                anchors.right: parent.right
                font.pixelSize: 20
                elide: Text.ElideRight
                color:"white"
                text: artist +" - "+name
                //text: "test"
            }
            Text {
                id: albumName
                anchors.left: ownerImg.right
                anchors.leftMargin: 10
                anchors.top: songName.bottom
                //anchors.topMargin: 5
                anchors.right: parent.right
                font.pixelSize: 16
                elide: Text.ElideRight
                color:"#cacaca"
                text: qsTr("Album: ")+album
                //text: "test1"
            }
            Text {
                id: dateName
                anchors.left: ownerImg.right
                anchors.leftMargin: 10
                anchors.top: albumName.bottom
                //anchors.topMargin: 5
                anchors.right: parent.right
                font.pixelSize: 16
                elide: Text.ElideRight
                color:"#cacaca"
                text: qsTr("Played: ")+date
                //text: "test2"
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    //if(myFavoritesPage.editing) {
                        selected = !selected;
                    //}
                }
            }

//            Connections {
//                target: myFavoritesPage
//                onEditingChanged: {
//                    if(editing == false)
//                        selected = false;
//                }
//            }
        }
    }

    // favoritesView
    ListView {
        id: favoritesView
        spacing: 15
        clip: true
        anchors.top: stationTopBar.bottom
        anchors.topMargin: 10
        anchors.bottom: {
            if(playbackProgressBarArea.visible)
            {
                return playbackProgressBarArea.top
            }
            else
            {
                return stationBottomBar.top
            }
        }
        anchors.left: parent.left
        anchors.leftMargin: 10
        anchors.right: parent.right
        delegate: favoritesDelegate
    }

    // playbackProgressBarArea
    Item {
        id: playbackProgressBarArea
        width: parent.width
        height: playbackProgressBarAreaBg.sourceSize.height
        anchors.bottom: stationBottomBar.top
        visible: {
            if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                return true;
            } else {
                return false;
            }
        }
        Image {
            id: playbackProgressBarAreaBg
            source: "../image/music_play_bg.png"
        }
        MediaPlaybackProgressBar {
            id: mediaPlaybackProgressBar
            anchors.verticalCenter: parent.verticalCenter
            value: context.currentPlayingPosition
            maximum: context.currentPlayingDuration
            leftmum: maximum - value
        }
    }

    // stationBottomBar
    Item {
        id: stationBottomBar
        width: parent.width
        height: mostStationsPageBottomBarBg.sourceSize.height
        anchors.bottom: parent.bottom
        onGoBack: {
            pageStack.pop();
        }

        signal goBack
        signal closeSoftPanel

        Image {
            id: mostStationsPageBottomBarBg
            source: "../image/bottom.png"
        }

        Item {
            id: goBack
            width: backBg.sourceSize.width
            height: parent.height
            anchors.left: parent.left
            anchors.leftMargin: 20
            Image {
                id: backBg
                anchors.centerIn: parent
                source: "../image/icon_bg.png"
                visible: {
                    if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                        return true;
                    } else {
                        return false;
                    }
                }
            }
            Image {
                anchors.centerIn: parent
                source: "../image/back.png"
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    stationBottomBar.goBack();
                    stationBottomBar.closeSoftPanel();
                    if(pageStack.depth==mainPage.mainViewDepth+1){
                        mainPage.currentOnlineFriends=0;
                        context.getOnlinFollowersNums();
                        context.getOnlinFollowingNums();
                        context.getUnReadInboxInfoNums();
                    }
                }
            }
        }

        Item {
            id: deleteStared
            width: deleteBg.sourceSize.width
            height: parent.height
            anchors.right: parent.right
            anchors.rightMargin: 20
            Image {
                id: deleteBg
                anchors.centerIn: parent
                source: "../image/icon_bg.png"
                visible: true
                }

            Image {
                anchors.centerIn: parent
                source: "../image/delete.png"
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    console.log("removendo stared song")
                    context.removeSelectedStarredSong()
                    }
                }
            }


        Item {
            id: playerController
            width: playerControllerBg.sourceSize.width
            height: playerControllerBg.sourceSize.height
            anchors.centerIn: parent
            visible: {
                if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                    return true;
                } else {
                    return false;
                }
            }

            Image {
                id: playerControllerBg
                anchors.centerIn: parent
                source: "../image/bottom_bg.png"
            }
            Item {
                id: playAndPauseArea
                anchors.left: parent.left
                width: parent.width / 2
                height: parent.height
                Image {
                    id: playAndPause
                    anchors.left: parent.left
                    anchors.leftMargin: 25
                    anchors.verticalCenter: playAndPauseArea.verticalCenter
                    source: {
                        if (context.mediaPlayerState == "playing") {
                            return "../image/pause.png"
                        } else {
                            return "../image/play.png"
                        }
                    }
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        stationBottomBar.closeSoftPanel();
                        if (!context.mediaPlayerLoading) {
                            if (context.mediaPlayerState == "playing") {
                                context.mediaPlayerPause();
                            } else {
                                context.mediaPlayerResume();
                            }
                        }
                    }
                }
            }
            Item {
                id: goToNextUpArea
                anchors.right: parent.right
                width: parent.width / 2
                height: parent.height
                visible:
                {
                    if(context.currentSongName==="")
                    {
                        return false;
                    }
                    else
                    {
                        return true
                    }
                }
                Image {
                    id: goToNextUp
                    anchors.right: parent.right
                    anchors.rightMargin: 25
                    anchors.verticalCenter: parent.verticalCenter
                    source: "../image/next.png"
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        stationBottomBar.closeSoftPanel();
                        if(context.clipSongPlaying)
                        {
                            if (context.nextUpSongId !== "") {
                                context.stopMediaPlayer();
                                context.playNextUpSong();
                                context.clipSongPlaying=false;
                            }
                        }
                        else
                        {
                            if (context.nextUpSongId !== "" && !context.mediaPlayerLoading) {
                                context.playNextUpSong();
                            } else {
                            }
                        }
                    }
                }
            }
        }

        BusyIndicator {
            anchors.centerIn: playerController
            platformStyle: BusyIndicatorStyle { size: "small" ;__invertedString: "inverted"}
            running: {
                if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                    if (context.mediaPlayerLoading) {
                        return true;
                    } else {
                        return false;
                    }
                } else {
                    return false
                }
            }
            visible: {
                if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                    if (context.mediaPlayerLoading) {
                        return true;
                    } else {
                        return false;
                    }
                } else {
                    return false
                }
            }
        }

        Item {
            id: openPlayer
            width: openPlayerIcon.sourceSize.width
            height: parent.height
//            anchors.right: menuBtn.left
//            anchors.rightMargin: 20
            anchors.right: parent.right
            anchors.rightMargin: (width *2) + 20
            visible: {
                if(context.currentSongName==="")
                {
                    return false;
                }
                else
                {
                    if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                        return true;
                    } else {
                        return false;
                    }
                }
            }
            Image {
                id: openPlayerIcon
                anchors.centerIn: parent
                source: "../image/music.png"
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    stationBottomBar.closeSoftPanel();
                    if(context.clipSongPlaying)
                    {
                        if (context.nextUpSongId !== "") {
                            context.stopMediaPlayer();
                            context.playNextUpSong();
                            context.clipSongPlaying=false;
                        }
                    }
                    pageStack.push(Qt.resolvedUrl("StationPlayer.qml"));
                }
            }
        }

//        Item {
//            id: menuBtn
//            width: backBg.sourceSize.width
//            height: parent.height
//            anchors.right: parent.right
//            anchors.rightMargin: 10
//            enabled: indicator.running == false
//            Image {
//                anchors.centerIn: parent
//                source: "../image/menu.png"
//            }
//            MouseArea {
//                anchors.fill: parent
//                onClicked: {
//                    if(myFavoritesPage.editing)
//                        editMenu.open()
//                    else
//                        mainMenu.open();
//                }
//            }
//        }
    }

    // indicator
    BusyIndicator {
        id: indicator
        anchors.centerIn: parent
        platformStyle: BusyIndicatorStyle { size: "large" }
        running: true
        //visible:false
    }

    Connections {
        target: context

        onGetFavoriteSongsFinished: {
            if(type===0)
            {
                favoritesView.model=favoriteSongModel;
                indicator.running=false;
                indicator.visible=false;
            }
            else
            {
                error.visible=true;
                error.text=errorInfo;
                indicator.running=false;
                indicator.visible=false;
            }
        }
        onMediaPlayerLoadingChanged: {
            if(context.mediaPlayerLoading===false)
            {
                indicator.running=false;
                indicator.visible=false;
                mask.visible=false;
            }
        }
    }

    Text {
        id: error
        anchors.centerIn: parent
        text:""
        color:"white"
        font.pixelSize: 30
        wrapMode:Text.WrapAnywhere
        visible: false
    }

    Rectangle {
        id: mask
        width: parent.width
        height: parent.height - stationBottomBar.height
        color: "black"
        opacity: 0.7
        visible: false
        MouseArea {
            anchors.fill: parent
            onClicked: {
            }
        }
    }

    //commented
//    Menu {
//        id: mainMenu
//        // define the items in the menu and corresponding actions
//        content: MenuLayout {
//            MenuItem {
//                text: qsTr("Edit Station")
//                onClicked: {
//                    myFavoritesPage.editing = true
//                }
//            }
//            MenuItem {
//                text: qsTr("Cancel")
//                onClicked: {
//                    myFavoritesPage.editing = false
//                    mainMenu.close()
//                }
//            }
//        }
//    }

//    Menu {
//        id: editMenu
//        // define the items in the menu and corresponding actions
//        content: MenuLayout {
//            MenuItem {
//                text: qsTr("Delete")
//                onClicked: {
//                    context.removeSelectedStarredSong()
//                    myFavoritesPage.editing = false
//                    editMenu.close()
//                }
//            }
//            MenuItem {
//                text: qsTr("Cancel")
//                onClicked: {
//                    myFavoritesPage.editing = false
//                    editMenu.close()
//                }
//            }
//        }
//    }

    //commented

    Component.onCompleted: {
        context.getFavoriteSongs();
    }
}
