import QtQuick 1.0
import com.nokia.meego 1.0

Item {
    id: myStationsViewer
    width: parent.width
    height: parent.height

    Connections {
        target: context
        onGetMyStationFinished: {
            indicator.running = false;
            indicator.visible = false;
            if (type === 0) {
                stationList.listViewModel = myStationsModel;
            }
        }
        onGetMyStationStarted: {
            indicator.running = true;
            indicator.visible = true;
        }
    }

    Image {
        id: backgroudImg
        width: parent.width
        height: parent.height
        source: "../image/home_bg.png"
    }

    StationsTopBar {
        id: stationTopBar
        stationIconSource: "../image/my_station_a.png"
        stationNameText: qsTr("My Stations")
    }

    Item {
        id: searchArea
        anchors.top: stationTopBar.bottom
        width: parent.width
        height: searchAreaBg.sourceSize.height
        Image {
            id: searchAreaBg
            anchors.fill: parent
            source: "../image/search_bg.png"
        }
        Image {
            id: searchBox
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.leftMargin: 10
            anchors.rightMargin: 10
            anchors.verticalCenter: parent.verticalCenter
            anchors.bottomMargin: 10
            source: "../image/search.png"
            Text {
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.leftMargin: 30
                anchors.rightMargin: 50
                anchors.verticalCenter: parent.verticalCenter
                font.pixelSize: 20
                elide: Text.ElideRight
                text: qsTr("Search for Artist to Create a Station")
                color: "gray"
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    pageStack.push(Qt.resolvedUrl("SearchArtistPage.qml"), {searchPurpose: "CREATESTATION"});
                }
            }
        }
        Image {
            id: icon
            anchors.right: parent.right
            anchors.rightMargin: 20
            anchors.verticalCenter: parent.verticalCenter
            source: "../image/icon_a.png"
        }
    }

    StationList {
        id: stationList
//        listViewModel: myStationsModel
        anchors.top: searchArea.bottom
        anchors.bottom: stationBottomBar.top
        anchors.topMargin: 10
        anchors.bottomMargin: 10
    }

    BusyIndicator {
        id: indicator
        anchors.centerIn: stationList
        platformStyle: BusyIndicatorStyle { size: "large" }
        running: true
    }

    StationsBottomBar {
        id: stationBottomBar
        anchors.bottom: parent.bottom
        onGoBack: {
            pageStack.pop();
        }
    }

    Item {
        id: playbackProgressBarArea
        width: parent.width
        height: playbackProgressBarAreaBg.sourceSize.height
        anchors.bottom: stationBottomBar.top
        visible: {
            if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                return true;
            } else {
                return false;
            }
        }
        Image {
            id: playbackProgressBarAreaBg
            source: "../image/music_play_bg.png"
        }
        MediaPlaybackProgressBar {
            id: mediaPlaybackProgressBar
            anchors.verticalCenter: parent.verticalCenter
            value: context.currentPlayingPosition
            maximum: context.currentPlayingDuration
            leftmum: maximum - value
        }
    }
    Component.onCompleted: {
        context.getMyStation();
    }
}
