import QtQuick 1.0
import com.nokia.meego 1.0
import "CommonUtil.js" as Util

Item {
    id: searchArtistPage
    property string searchPurpose: ""
    property string stationId: ""

    width: parent.width
    height: parent.height

    function doAutoSearch(){
        if(timer.running == false)
            timer.start();
        else{
            timer.restart();
        }
    }

    Connections {
        target: context
        onSearchArtistsFinished: {
            indicator.running = false;
            indicator.visible = false;
            if (type === 0) {
                artistList.model = searchedArtistsModel;
            }
        }
    }

    MouseArea {
        anchors.fill: parent
        onClicked: {
            searchInput.closeSoftwareInputPanel();
        }
    }

    Image {
        id: backgroudImg
        width: parent.width
        height: parent.height
        source: "../image/home_bg.png"
    }

    Image {
        id: stationToBar
        width: parent.width
        source: "../image/top_bar.png"
        Image {
            id: stationIcon
            anchors.left: parent.left
            anchors.leftMargin: 5
            anchors.verticalCenter: parent.verticalCenter
            source: "../image/cancel_a.png"
            Text {
                anchors.centerIn: parent
                color: "white"
                font.pixelSize: 20
                text: qsTr("Cancel")
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    pageStack.pop();
                    searchInput.closeSoftwareInputPanel();
                }
            }
        }
    }
    Item {
        id: searchArea
        anchors.top: stationToBar.bottom
        width: parent.width
        height: searchAreaBg.sourceSize.height
        Image {
            id: searchAreaBg
            anchors.fill: parent
            source: "../image/search_bg.png"
        }
        Image {
            id: searchBox
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.leftMargin: 10
            anchors.rightMargin: 10
            anchors.verticalCenter: parent.verticalCenter
            anchors.bottomMargin: 10
            source: "../image/search.png"
            TextInput {
                id: searchInput
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.leftMargin: 15
                anchors.rightMargin: 50
                anchors.verticalCenter: parent.verticalCenter
                font.pixelSize: 20
                color: "black"

                onTextChanged: {
                    doAutoSearch();
                }
            }
        }
        Image {
            id: icon
            anchors.right: parent.right
            anchors.rightMargin: 20
            anchors.verticalCenter: parent.verticalCenter
            source: "../image/icon_a.png"
        }
    }
    ListView {
        id: artistList
        width: parent.width
        anchors.top: searchArea.bottom
        anchors.bottom: parent.bottom
        clip: true
        delegate: Rectangle {
            width: ListView.view.width
            height: 80
            color: "transparent"
            Text {
                width: parent.width
                anchors.left: parent.left
                anchors.leftMargin: 20
                anchors.verticalCenter: parent.verticalCenter
                elide: Text.ElideRight
                color: "white"
                font.pixelSize: 30
                text: artistName
            }
            Rectangle {
                anchors.bottom: parent.bottom
                width: parent.width
                height: 1
                color: "white"
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    searchInput.closeSoftwareInputPanel();
                    if (searchArtistPage.searchPurpose == "CREATESTATION") {
                        context.createStation(artistId, artistName);
                        pageStack.push(Qt.resolvedUrl("StationPlayer.qml"), {stationName: artistName});
                    } else if (searchArtistPage.searchPurpose == "ADDARTIST") {
                        context.addArtist(searchArtistPage.stationId, artistId);
                        pageStack.pop();
                    }
                }
            }
        }
    }

    BusyIndicator {
        id: indicator
        anchors.centerIn: artistList
        platformStyle: BusyIndicatorStyle { size: "large" }
        running: false
        visible: false
    }

    Timer {
        id: timer
        interval: 700
        repeat: false
        running: false
        onTriggered: {
            indicator.running = true;
            indicator.visible = true;
            context.searchArtists(Util.trim(searchInput.text));
        }
    }
}
