import QtQuick 1.0
import com.nokia.meego 1.0
import "CommonComponent"

Rectangle {
    width: parent.width
    height: parent.height
    Image {
        id: bg
        source:  "../image/home_bg.png"
    }
    property real leftMargin: 10
    property real rightMargin: 10
    property real buttonWidth: 70
    property real defaultFontSize: 21
    property real buttonMargin:2
    property string result:""
    Text {
        id: caption
        anchors.top: stationTopBar.bottom
        anchors.topMargin: 20
        anchors.rightMargin:rightMargin+buttonWidth
        anchors.leftMargin: leftMargin
        anchors.left: parent.left
        anchors.right: parent.right
        height: 50
        text: qsTr("These Settings controls if your stations and their locations are publicly visible.")
        wrapMode:Text.WrapAnywhere
        color:"white"
        font.pixelSize:defaultFontSize
        font.bold:true
    }

    ListModel {
        id: sharingPreferencesModel
        ListElement {
            //name: "Broadcast Stations"
        }
        ListElement {
            //name: "Share Geo-location"
        }
        function name(index)
        {
            switch(index)
            {
            case 0:
                return qsTr("Broadcast Stations");
            case 1:
                return qsTr("Share Geo-location");
            }
        }
    }

    Component {
        id: sharingPreferencesDelegate
        Item
        {
            id:buttonItem
            width:sharingPreferencesView.width;
            height:40

            Switch{
                id:switchkButton
                anchors.verticalCenter: parent.verticalCenter
                anchors.right: parent.right
                anchors.rightMargin: 20
                checked:
                {
                    if(index===0)
                    {
                        return context.isBroadcastMusic();
                    }else
                    {
                        return context.isShareLocation();
                    }
                }

                platformStyle: SwitchStyle {__invertedString: "-inverted"}
                onCheckedChanged: {
                    if(index===0)
                    {
                        context.setBroadcastMusic(checked);
                        mainPage.localDataStorage.modifyBroadcastMusic(context.isBroadcastMusic(),context.isShareLocation());
                    }
                    else
                    {
                        context.setShareLocation(checked);
                        mainPage.localDataStorage.modifyShareLocation(context.isBroadcastMusic(),context.isShareLocation());
                    }
                    //mainPage.localDataStorage.modify(context.isBroadcastMusic(),context.isShareLocation());
                    //console.log(result);
                }
            }
            Text
            {
                id:itemText
                //height: parent.height
                anchors.left: parent.left
                anchors.right: switchkButton.left
                anchors.verticalCenter: switchkButton.verticalCenter
                //anchors.rightMargin: buttonWidth+rightMargin
                font.pixelSize: defaultFontSize
                color:"white"
                text:sharingPreferencesView.model.name(index)
            }
        }
    }
    ListView {
        id: sharingPreferencesView
        spacing: 20
        clip: true
        anchors.topMargin: spacing
        anchors.top: caption.bottom
        anchors.bottom: parent.bottom
        anchors.leftMargin: leftMargin
        anchors.rightMargin: rightMargin
        anchors.left: parent.left
        anchors.right: parent.right
        model: sharingPreferencesModel
        delegate: sharingPreferencesDelegate
        interactive:false
    }

    StationsTopBar {
        id: stationTopBar
        stationNameText: qsTr("Sharing Preferences")
    }

    Item {
        id: playbackProgressBarArea
        width: parent.width
        height: playbackProgressBarAreaBg.sourceSize.height
        anchors.bottom: stationBottomBar.top
        visible: {
            if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                return true;
            } else {
                return false;
            }
        }
        Image {
            id: playbackProgressBarAreaBg
            source: "../image/music_play_bg.png"
        }
        MediaPlaybackProgressBar {
            id: mediaPlaybackProgressBar
            anchors.verticalCenter: parent.verticalCenter
            value: context.currentPlayingPosition
            maximum: context.currentPlayingDuration
            leftmum: maximum - value
        }
    }

    StationsBottomBar {
        id: stationBottomBar
        anchors.bottom: parent.bottom
        onGoBack: {
            pageStack.pop();
        }
    }
}
