import QtQuick 1.0
import com.nokia.meego 1.0
import "CommonComponent" as CommonComponent

Rectangle {
    id: soundTrackerLoginPage
    width: parent.width
    height: parent.height

    property bool errorInfoStatus: false

    function isEmail(str) {
           var reg = /^([a-zA-Z0-9_.-])+@([a-zA-Z0-9_-])+((\.[a-zA-Z0-9_-]{2,3}){1,2})$/;
           return reg.test(str);
    }

    Connections {
        target: context
        onLoginFinished: {
            if(mainPage.stLoginFrom == "login"){
                mask.visible = false;
                indicator.running = false;
                indicator.visible = false;
                if (type === 0) {
                    mainPage.localstorage.save(accountInput.text,pwdInput.text,3);
                    pageStack.push(Qt.resolvedUrl("SoundTrackerMain.qml"));
                    mainPage.mainViewDepth=3;
                }else if(type === 1){
                    warningIcon.visible=true;
                    errorInfo.text = qsTr("Login failed. Please try again.");
                    errorInfoStatus = true;
                }else if(type==2){
                    warningIcon.visible=true;
                    errorInfo.text = qsTr("Incorrect Email and Password combination. Please check this and try again.");
                    errorInfoStatus = true;
                }
            }
        }
    }

    MouseArea {
        anchors.fill: parent
        onClicked: {
            accountInput.closeSoftwareInputPanel();
            pwdInput.closeSoftwareInputPanel();
        }
    }

    Image {
        id: bg
        source: "../image/home_bg.png"
        width: parent.width
        height:parent.height
    }

    CommonComponent.CancelDoneTopBar {
        id: topBar
        cancelText: qsTr("Cancel")
        doneText: qsTr("Done")
        onCancel: {
            accountInput.closeSoftwareInputPanel();
            pwdInput.closeSoftwareInputPanel();
            pageStack.pop();
        }
        onDone: {
            accountInput.closeSoftwareInputPanel();
            pwdInput.closeSoftwareInputPanel();
            if(accountInput.text==""||pwdInput.text==""){
                warningIcon.visible=true;
                errorInfo.text=qsTr("Username and password can not be empty!");
                errorInfoStatus = true;
            }else if(!isEmail(accountInput.text)){
                warningIcon.visible=true;
                errorInfo.text=qsTr("Please enter a valid Email address!");
                errorInfoStatus = true;
            }else{
                mask.visible = true;
                indicator.running=true;
                indicator.visible=true;
                errorInfo.text="";
                warningIcon.visible=false;
                context.login(accountInput.text,pwdInput.text);
            }
        }
    }

    // signInLabel
    Text {
        id: signInLabel
        text: qsTr("Sign in to Soundtracker")
        color: "white"
        font.pixelSize: 30
        font.bold: true
        anchors.top: topBar.bottom
        anchors.topMargin: 30
        anchors.left: parent.left
        anchors.leftMargin: 20
    }

    // userName
    Text {
        id: userName
        text: qsTr("Email")
        color: "gray"
        font.bold: true
        font.pixelSize: 24
        anchors.top: signInLabel.bottom
        anchors.topMargin: 10
        anchors.left: signInLabel.left
    }

    Image {
        id: accountInputBg
        source: "../image/search.png"
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top:userName.bottom
    }

    TextInput {
        id: accountInput
        anchors.verticalCenter: accountInputBg.verticalCenter
        anchors.left: accountInputBg.left
        anchors.leftMargin: 10
        anchors.right: accountInputBg.right
        anchors.rightMargin: 10
        font.pixelSize: 24
//        text: "ui1234@yahoo.cn"
    }

    Text {
        id: passWord
        text: qsTr("Password")
        color: "gray"
        font.bold: true
        font.pixelSize: 24
        anchors.top: accountInputBg.bottom
        anchors.topMargin: 10
        anchors.left: signInLabel.left
    }

    // pwdInputBg
    Image {
        id: pwdInputBg
        source: "../image/search.png"
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top:passWord.bottom
    }

    // pwdInput
    TextInput {
        id: pwdInput
        anchors.verticalCenter: pwdInputBg.verticalCenter
        anchors.left: pwdInputBg.left
        anchors.leftMargin: 10
        anchors.right: pwdInputBg.right
        anchors.rightMargin: 10
        font.pixelSize: 24
        echoMode: TextInput.Password
//        text: "123456789"
    }

    // warningIcon
    Image {
        id: warningIcon
        source: "../image/warning.png"
        visible: false
        anchors.left: signInLabel.left;
        anchors.top: pwdInputBg.bottom
        anchors.topMargin: 10
    }

    // errorInfo
    Text {
        id: errorInfo
        anchors.left: warningIcon.right
        anchors.leftMargin: 10
        anchors.top: warningIcon.top
        wrapMode: Text.Wrap
        width: parent.width-50
        color: "red"
        font.pixelSize: 24
    }

    // forgetPwdBtn
    Rectangle {
        id: forgetPwdBtn
        anchors.top: pwdInputBg.bottom
        anchors.topMargin: 90
        anchors.left: signInLabel.left
        width: 200
        height: 50
        color: "transparent"
        Text {
            text: qsTr("Forgot Password")
            font.bold: true
            font.pixelSize: 24
            anchors.left: forgetPwdBtn.left
            anchors.verticalCenter: forgetPwdBtn.verticalCenter
            color: "white"
        }
        MouseArea {
            anchors.fill: parent
            onClicked: {
                accountInput.closeSoftwareInputPanel();
                pwdInput.closeSoftwareInputPanel();
                pageStack.push(Qt.resolvedUrl("ForgetPassword.qml"));
            }
        }
    }

    // signUpBtn
    Rectangle {
        id: signUpBtn
        anchors.top: forgetPwdBtn.bottom
        anchors.topMargin: 30
        anchors.left:signInLabel.left
        width: 200
        height: 50
        color: "transparent"
        Text {
            text: qsTr("Sign up")
            font.bold: true
            font.pixelSize: 24
            anchors.left: signUpBtn.left
            anchors.verticalCenter: signUpBtn.verticalCenter
            color: "white"
        }
        MouseArea{
            anchors.fill: parent
            onClicked: {
                accountInput.closeSoftwareInputPanel();
                pwdInput.closeSoftwareInputPanel();
                pageStack.push(Qt.resolvedUrl("SoundTrackerSignUp.qml"));
            }
        }
    }

    Rectangle {
        id: mask
        width: parent.width
        height: parent.height
        color: "transparent"
        visible: false

        MouseArea {
            anchors.fill: parent
            onClicked: {}
        }

        BusyIndicator {
            id: indicator
            platformStyle: BusyIndicatorStyle { size: "large" }
            running: false
            visible: false
            anchors.centerIn: parent
        }
    }

    Timer{
        id: timer
        running: errorInfoStatus
        interval: 4000
        onTriggered: {
            warningIcon.visible=false;
            errorInfo.text=""
            errorInfoStatus=false;
        }
    }
}

