import QtQuick 1.0
import com.nokia.meego 1.0
import "CommonUtil.js" as Util

Rectangle {
    id:signUpPage
    width: parent.width
    height: parent.height

    property bool errorInfoStatus: false
    property int profilePicStatus: 0
    property bool upLoadPicFailed: false
    property bool fromSignUp: false

    function isEmail(str){
        var reg = /^([a-zA-Z0-9_.-])+@([a-zA-Z0-9_-])+((\.[a-zA-Z0-9_-]{2,3}){1,2})$/;
        return reg.test(str);
    }
    Connections {
        target: context
        onUpdateProfilePicFinished: {
            if(fromSignUp){
                if (type === 0) {
                    indicator.running = false;
                    indicator.visible = false;
                    profilePicStatus = 0;
                    pageStack.replace(Qt.resolvedUrl("SoundTrackerMain.qml"));
                    mainPage.mainViewDepth=3;
                }else if(type === 1){
                    indicator.running = false;
                    indicator.visible = false;
                    profilePicStatus = 1;
                    warningIcon.visible=true;
                    signUpPage.upLoadPicFailed=true;
                    errorInfo.text = qsTr("Update picture failed. Please try again.");
                    errorInfoStatus = true;
                }
            }
        }
        onProfilePictureChanged: {
            if(fromSignUp){
                profilePicStatus = 1;
                avatarImg.source = avatarPath;
            }
        }
        onCreateAccountFinished:{
            if(fromSignUp){
                if(type ===0 ){
                    context.loginAfterCreate(emailInput.text,vpInput.text);
                }else if(type == 1){
                    indicator.running = false;
                    indicator.visible = false;
                    warningIcon.visible=true;
                    errorInfo.text=qsTr("Create Acount failed. Please try again.");
                    errorInfoStatus=true;
                }else if(type ==2){
                    indicator.running = false;
                    indicator.visible = false;
                    warningIcon.visible=true;
                    errorInfo.text=qsTr("The email address has been used. Please change to another and try again.");
                    errorInfoStatus=true;
                }
            }
        }
        onLoginAfterCreateFinished:{
            if (type === 0) {
                if(profilePicStatus){
                    context.updateProfilePicture(avatarImg.source);
                }else{
                    indicator.running = false;
                    indicator.visible = false;
                    pageStack.replace(Qt.resolvedUrl("SoundTrackerMain.qml"));
                    mainPage.mainViewDepth=3;
                }
            }else{
                indicator.running = false;
                indicator.visible = false;
                warningIcon.visible=true;
                errorInfo.text=qsTr("Create Acount Successed,login failed. Please try to login again.");
                errorInfoStatus=true;
            }
        }
    }

    MouseArea{
        anchors.fill:parent
        onClicked: {
            fnInput.closeSoftwareInputPanel();
            lnInput.closeSoftwareInputPanel();
            emailInput.closeSoftwareInputPanel();
            pwdInput.closeSoftwareInputPanel();
            vpInput.closeSoftwareInputPanel();
        }
    }
    Rectangle{
        id:bottonLn
        width: parent.width
        height: 20
        color: "transparent"
        anchors.bottom: parent.bottom
    }

    Image {
        id: backgroudImg
        width: parent.width
        height: parent.height
        source: "../image/home_bg.png"
    }

    Image {
        id: topBarBg
        source: "../image/top_bar.png"
    }

    Rectangle{
        id:cancelBtn
        anchors.left: parent.left
        anchors.leftMargin: 30
        anchors.verticalCenter: topBarBg.verticalCenter
        width: cancelBtnBg.sourceSize.width
        height: cancelBtnBg.sourceSize.height
        color: "transparent"
        Image {
            id: cancelBtnBg
            source: "../image/cancel_a.png"
        }
        Text {
            text: qsTr("Cancel")
            font.bold: true
            font.pixelSize: 24
            color: "white"
            anchors.centerIn: cancelBtnBg
        }
        MouseArea{
            anchors.fill:parent
            onClicked: {
                fnInput.closeSoftwareInputPanel();
                lnInput.closeSoftwareInputPanel();
                emailInput.closeSoftwareInputPanel();
                pwdInput.closeSoftwareInputPanel();
                vpInput.closeSoftwareInputPanel();
                pageStack.pop();
            }
        }
    }

    Rectangle{
        id:doneBtn
        anchors.right:parent.right
        anchors.rightMargin: 30
        anchors.verticalCenter: topBarBg.verticalCenter
        width: doneBtnBg.sourceSize.width
        height: doneBtnBg.sourceSize.height
        color: "transparent"
        Image {
            id: doneBtnBg
            source: "../image/cancel_a.png"
        }
        Text {
            text: "Done"
            font.bold: true
            font.pixelSize: 24
            color: "white"
            anchors.centerIn: doneBtnBg
        }
        MouseArea{
            anchors.fill: parent
            onClicked: {
                fnInput.closeSoftwareInputPanel();
                lnInput.closeSoftwareInputPanel();
                emailInput.closeSoftwareInputPanel();
                pwdInput.closeSoftwareInputPanel();
                vpInput.closeSoftwareInputPanel();

                if(fnInput.text===""||lnInput.text===""
                        || emailInput.text===""||pwdInput.text===""
                        || vpInput.text===""){
                    warningIcon.visible=true;
                    errorInfo.text=qsTr("Account profile can not be empty!");
                    errorInfoStatus = true;
                }else if(pwdInput.text !== vpInput.text){
                    warningIcon.visible=true;
                    errorInfo.text=qsTr("Password and confirmation password should be same!");
                    errorInfoStatus = true;
                }else if(!isEmail(emailInput.text)){
                    warningIcon.visible=true;
                    errorInfo.text=qsTr("Please enter a valid Email address!");
                    errorInfoStatus = true;
                }else if(pwdInput.text.length<6){
                    warningIcon.visible=true;
                    errorInfo.text=qsTr("password must be at least 6 characters long!");
                    errorInfoStatus = true;
                }else if(fnInput.text.length>50){
                    warningIcon.visible=true;
                    errorInfo.text=qsTr("First name must be less than 50 characters long!");
                    errorInfoStatus = true;
                }else if(lnInput.text.length>40){
                    warningIcon.visible=true;
                    errorInfo.text=qsTr("Last name must be less than 40 characters long!");
                    errorInfoStatus = true;
                }else{
                    indicator.running=true;
                    indicator.visible=true;
                    errorInfo.text="";
                    warningIcon.visible=false;
                    fromSignUp=true;
                    context.createAccount(fnInput.text, lnInput.text,
                                          emailInput.text, vpInput.text);
                }
            }
        }
    }

    Item {
        id: logo
        anchors.top: topBarBg.bottom
        anchors.topMargin: 15
        anchors.left: parent.left
        anchors.leftMargin: 10

        width: 182;
        height: width;
        smooth: true

        Image {
            id: defaultImg
            width: parent.width - 2
            height: width
            anchors.centerIn: parent
            source: Util.getRandomDefaultThumb();
        }
        Image {
            id: avatarImg
            scale: 0.0
            width: parent.width - 2
            height: width
            anchors.centerIn: parent
        }
    }

    Image {
        id: btnBg
        source: "../image/others.png"
        anchors.verticalCenter: logo.verticalCenter
        anchors.left: logo.right
        anchors.leftMargin: 30
        anchors.right: parent.right
        anchors.rightMargin: 30

        Text {
            text: qsTr("Change Picture")
            font.bold: true
            font.pixelSize: 24
            color: "white"
            anchors.centerIn: btnBg
        }
        MouseArea{
            anchors.fill: parent
            onClicked: {
                fnInput.closeSoftwareInputPanel();
                lnInput.closeSoftwareInputPanel();
                emailInput.closeSoftwareInputPanel();
                pwdInput.closeSoftwareInputPanel();
                vpInput.closeSoftwareInputPanel();
                fromSignUp=true;
                changeMothod.visible = true;
            }
        }
    }

    Flickable{
        id:personalContainer
        width: parent.width
        anchors.top: logo.bottom
        anchors.bottom: bottonLn.top
        clip: true
        contentHeight: firstName.height*6+180
        Text {
            id: firstName
            text: qsTr("First name:")
            color: "green"
            font.bold: false
            font.pixelSize: 24
            anchors.top: parent.top
            anchors.topMargin: 20
            anchors.left: parent.left
            anchors.leftMargin: 20
        }
        TextInput{
            id:fnInput
            anchors.top: firstName.top
            anchors.left: firstName.right
            anchors.leftMargin: 10
            anchors.right: parent.right
            anchors.rightMargin: 10
            font.pixelSize: 24
            color: "white"
        }

        Text {
            id: lastName
            text: qsTr("Last name:")
            color: "green"
            font.bold: false
            font.pixelSize: 24
            anchors.top: firstName.bottom
            anchors.topMargin: 30
            anchors.left: parent.left
            anchors.leftMargin: 20
        }
        TextInput{
            id:lnInput
            anchors.top: lastName.top
            anchors.left: lastName.right
            anchors.leftMargin: 10
            anchors.right: parent.right
            anchors.rightMargin: 10
            font.pixelSize: 24
            color: "white"
        }

        Text {
            id: email
            text: qsTr("Email") + ":"
            color: "green"
            font.bold: false
            font.pixelSize: 24
            anchors.top: lastName.bottom
            anchors.topMargin: 30
            anchors.left: parent.left
            anchors.leftMargin: 20
        }
        TextInput{
            id:emailInput
            anchors.top: email.top
            anchors.left: email.right
            anchors.leftMargin: 10
            anchors.right: parent.right
            anchors.rightMargin: 10
            font.pixelSize: 24
            color: "white"
        }

        Text {
            id: passWord
            text: qsTr("Password:")
            color: "green"
            font.bold: false
            font.pixelSize: 24
            anchors.top: emailInput.bottom
            anchors.topMargin: 30
            anchors.left: parent.left
            anchors.leftMargin: 20
        }
        TextInput{
            id:pwdInput
            anchors.top: passWord.top
            anchors.left: passWord.right
            anchors.leftMargin: 10
            anchors.right: parent.right
            anchors.rightMargin: 10
            font.pixelSize: 24
            echoMode: TextInput.Password
            color: "white"
        }

        Text {
            id: verifyPsassWord
            text: qsTr("Verify password:")
            color: "green"
            font.bold: false
            font.pixelSize: 24
            anchors.top: passWord.bottom
            anchors.topMargin: 30
            anchors.left: parent.left
            anchors.leftMargin: 20
        }
        TextInput{
            id:vpInput
            anchors.top: verifyPsassWord.top
            anchors.left: verifyPsassWord.right
            anchors.leftMargin: 10
            anchors.right: parent.right
            anchors.rightMargin: 10
            font.pixelSize: 24
            echoMode: TextInput.Password
            color: "white"
        }
        Text {
            id: horizontalSeperator
            anchors.left: privacyPolicy.right
            anchors.leftMargin: 10
            anchors.verticalCenter: privacyPolicy.verticalCenter
            font.pixelSize: 30
            color: "white"
            text: "|"
        }

        Text {
            id: privacyPolicy
            anchors.top: verifyPsassWord.bottom
            anchors.topMargin: 50
            anchors.left: parent.left
            anchors.leftMargin: 20
            font.pixelSize: 20
            font.bold: true
            textFormat: Text.RichText
            text: "<a href=\"http://www.soundtracker.fm/app/tos\" style=\"color:white\">" + qsTr("Terms of Service") + "</a>"
            onLinkActivated: {
                pageStack.push(Qt.resolvedUrl("Tos.qml"))
            }
        }

        Text {
            id: termsService
            anchors.left: horizontalSeperator.right
            anchors.leftMargin: 10
            anchors.verticalCenter: horizontalSeperator.verticalCenter
            font.pixelSize: 20
            textFormat: Text.RichText
            font.bold: true
            text: "<a href=\"http://www.soundtracker.fm/app/privacy\" style=\"color:white\">" + qsTr("Privacy Policy") + "</a>"
            onLinkActivated: {
                pageStack.push(Qt.resolvedUrl("PrivacyPolicy.qml"))
            }
        }
        Image {
            id: warningIcon
            source: "../image/warning.png"
            visible: false
            anchors.left: parent.left
            anchors.leftMargin: 20
            anchors.top: privacyPolicy.bottom
            anchors.topMargin: 10
        }
        Text {
            id: errorInfo
            anchors.left: warningIcon.right
            anchors.leftMargin: 10
            anchors.verticalCenter: warningIcon.verticalCenter
            wrapMode: Text.Wrap
            width: parent.width-50
            color: "red"
            font.pixelSize: 20
        }
    }



    BusyIndicator {
        id: indicator
        platformStyle: BusyIndicatorStyle { size: "large" }
        running: false
        visible: false
        anchors.centerIn: parent
    }



    Rectangle {
        id: changeMothod
        width: parent.width
        height: 200
        anchors.bottom: parent.bottom
        color: "black"
        visible: false

        Image {
            id: localBtn
            source: "../image/others.png"
            anchors.top: parent.top
            anchors.topMargin: 10
            anchors.left: parent.left
            anchors.leftMargin: 20
            anchors.right: parent.right
            anchors.rightMargin: 20

            Text {
                text: qsTr("Local photo")
                font.bold: true
                font.pixelSize: 24
                color: "white"
                anchors.centerIn: localBtn
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    changeMothod.visible = false
                    pageStack.push(Qt.resolvedUrl("GalleryViewer.qml"))
                }
            }
        }

        Image {
            id: cameraBtn
            source: "../image/others.png"
            anchors.left: parent.left
            anchors.leftMargin: 20
            anchors.right: parent.right
            anchors.rightMargin: 20
            anchors.verticalCenter: parent.verticalCenter

            Text {
                text: qsTr("Capture Photo")
                font.bold: true
                font.pixelSize: 24
                color: "white"
                anchors.centerIn: cameraBtn
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    changeMothod.visible = false
                    pageStack.push(Qt.resolvedUrl("CameraPage.qml"))
                }
            }
        }

        Image {
            id: returnBtn
            source: "../image/others.png"
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 10
            anchors.left: parent.left
            anchors.leftMargin: 20
            anchors.right: parent.right
            anchors.rightMargin: 20

            Text {
                text: qsTr("Cancel")
                font.bold: true
                font.pixelSize: 24
                color: "white"
                anchors.centerIn: returnBtn
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    changeMothod.visible = false
                }
            }
        }
    }

    Timer{
        id: timer
        running: errorInfoStatus
        interval: 4000
        onTriggered: {
            warningIcon.visible=false;
            errorInfo.text=""
            errorInfoStatus=false;
        }
    }
    Timer{
        id: timer2
        running: upLoadPicFailed
        interval: 2000
        onTriggered: {
            pageStack.replace(Qt.resolvedUrl("SoundTrackerMain.qml"));
            upLoadPicFailed=false;
        }
    }

    states: [
        State {
            name: "Show"; when: avatarImg.status == Image.Ready
            PropertyChanges { target: avatarImg; scale: 1 }
            PropertyChanges {target: defaultImg; visible: false}
        }
    ]
    transitions: [
        Transition {
            NumberAnimation {
                properties: "scale"; duration: 500; easing.type: Easing.InOutQuad
            }
        }
    ]
}
