import QtQuick 1.0
import com.nokia.meego 1.0
import "CommonUtil.js" as Util

Rectangle {
    id:specifyFriendStations
    width: parent.width
    height: parent.height

    property string friendId
    property string friendName
    property string friendLocation
    property string friendPhoto
    property string followersNum
    property string followingNum

    Connections {
        target: context
        onGetSpecifyFriendStationFinished: {
            mask.visible = false;
            indicator.running = false;
            indicator.visible = false;
            friendStationsList.model=specifyFriendStationModel;
            stationCountNum.text=stationNum;
        }
    }

    Image {
        id: backgroudImg
        width: parent.width
        height: parent.height
        source: "../image/home_bg.png"
    }
    
    StationsTopBar {
        id: stationTopBar
        stationNameText: friendName
    }
    
    Image {
        id: friendAvatar
        source: friendPhoto
        anchors.top:stationTopBar.bottom
        width: parent.width
        height:(parent.height-stationTopBar.height-stationBottomBar.height)/2

        Rectangle{
            id:friendInfoContainer
            width: parent.width
            height: 100
            color: "black"
            opacity: 0.7
            anchors.bottom: parent.bottom
            Text {
                id: friendsname
                text: friendName
                anchors.top:parent.top
                anchors.topMargin: 20
                anchors.left: parent.left
                anchors.leftMargin: 20
                color: "white"
                font.bold: true
                font.pixelSize: 24
            }
            Text {
                id: friendslocation
                text: friendLocation
                anchors.top:friendsname.bottom
                anchors.topMargin: 10
                anchors.left: parent.left
                anchors.leftMargin: 20
                color: "white"
                font.pixelSize: 24
            }
            Image {
                id: chartBtn
                source: "../image/talk_icon.png"
                anchors.right: parent.right
                anchors.rightMargin: 20
                anchors.verticalCenter: parent.verticalCenter
                MouseArea{
                    anchors.fill: parent
                    onClicked: {
                        pageStack.push(Qt.resolvedUrl("ChatWithFriend.qml"),{userId:friendId});
                    }
                }
            }
        }
    }
    Text {
        id: stationCountNum
        anchors.top:friendAvatar.bottom
        anchors.topMargin: 20
        anchors.left: parent.left
        anchors.leftMargin: 20
        font.bold:true
        font.pixelSize: 24
        color: "white"
    }
    Text {
        id: stationCount
        text: qsTr("Stations")
        anchors.top:friendAvatar.bottom
        anchors.topMargin: 20
        anchors.left: stationCountNum.right
        anchors.leftMargin: 20
        font.bold:true
        font.pixelSize: 24
        color: "white"
    }
    Rectangle{
        id:line
        anchors.left: parent.left
        anchors.leftMargin: 10
        anchors.right: parent.right
        anchors.rightMargin: 10
        anchors.top: stationCount.bottom
        anchors.topMargin: 10
        height: 1
        color: "white"
    }
    ListView{
        id:friendStationsList
        width: parent.width
        anchors.top:line.bottom
        anchors.bottom:stationBottomBar.top
        clip: true
        delegate: Rectangle {
            width: friendStationsList.width
            height: 100
            color: "transparent"
            Rectangle{
                id:stationIcon
                width:100
                height:100
                color: "transparent"
                Image {
                    id: defaultImg
                    width: 90
                    height: width
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.left: parent.left
                    anchors.leftMargin: 10
                    source: Util.getRandomDefaultThumb();
                }
                Image {
                    id: stationImage
                    width: 90
                    height: width
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.left: defaultImg.left
                    scale: 0.0
                    source: image
                }
            }

            Text {
                id: title
                anchors.top: parent.top
                anchors.topMargin: 10
                anchors.left: stationIcon.right
                anchors.leftMargin: 10
                anchors.right: parent.right
                elide: Text.ElideRight
                color: "white"
                font.pixelSize: 20
                text: stationName
            }
            Text {
                id: lastPlayedTime
                anchors.left: title.left
                anchors.top: title.bottom
                color: "white"
                font.pixelSize: 16
                text: {
                    var lpt = lastPlayedTs.split("-");
                    var flag = lpt[1];
                    var nums = lpt[0];
                    if (flag == "s") {
                        return qsTr("Last played:")+" " + nums +" "+ qsTr("seconds ago");
                    } else if (flag == "m") {
                        return qsTr("Last played:")+" " + nums+" " + qsTr("minutes ago");
                    } else if (flag == "h") {
                        return qsTr("Last played:")+" " + nums+" " + qsTr("hours ago");
                    } else if (flag == "d") {
                        return qsTr("Last played:")+" " + nums+" " + qsTr("days ago");
                    } else if (flag == "y") {
                        return qsTr("Last played:")+" " + nums+" " + qsTr("years ago");
                    }
                }
            }
            Text {
                id: createdTime
                anchors.left: title.left
                anchors.top: lastPlayedTime.bottom
                color: "white"
                font.pixelSize: 16
                text: {
                    var lpt = createdTs.split("-");
                    var flag = lpt[1];
                    var nums = lpt[0];
                    if (flag == "s") {
                        return qsTr("Created:")+" " + nums+" " + qsTr("seconds ago");
                    } else if (flag == "m") {
                        return qsTr("Created:")+" " + nums+" " + qsTr("minutes ago");
                    } else if (flag == "h") {
                        return qsTr("Created:")+" " + nums+" " + qsTr("hours ago");
                    } else if (flag == "d") {
                        return qsTr("Created:")+" " + nums+" " + qsTr("days ago");
                    } else if (flag == "y") {
                        return qsTr("Created:")+" " + nums+" " + qsTr("years ago");
                    }
                }
            }
            states: [
                 State {
                     name: "Show"; when: stationImage.status == Image.Ready
                     PropertyChanges { target: stationImage; scale: 1 }
                     PropertyChanges {target: defaultImg; visible: false}
                 }
             ]
             transitions: [
                 Transition {
                     NumberAnimation {
                         properties: "scale"; duration: 500; easing.type: Easing.InOutQuad
                     }

                 }
             ]
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    context.getNextSong(stationId,stationName);
                    pageStack.push(Qt.resolvedUrl("StationPlayer.qml"));
                }
            }
        }
    }

    Item{
        id:stationBottomBar
        width: stationBottomBarBg.sourceSize.width
        height: stationBottomBarBg.sourceSize.height
        anchors.bottom: parent.bottom
        Image {
            id: stationBottomBarBg
            source: "../image/bottom.png"
        }

        MyButton{
            id:goBack
            anchors.left: parent.left
            anchors.verticalCenter: parent.verticalCenter
            image: "../image/back.png"
            imagePressed: "../image/back.png"
            onClicked: {
                pageStack.pop();
            }
        }
        MyButton{
            id:friendsNumbersBtn
            anchors.right: parent.right
            anchors.verticalCenter: parent.verticalCenter
            image: "../image/menu.png"
            imagePressed: "../image/menu.png"
            onClicked: {
                friendFollowNumberPage.state="ShowUp";
                friendFollowNumberPage.maskB.visible=true;
                friendFollowNumberPage.indicator1.visible=true;
                friendFollowNumberPage.indicator1.running=true;
                context.getIsMyfriend(friendId);
            }
        }
    }

    Rectangle{
        id:mask
        width: parent.width
        anchors.top:friendAvatar.bottom
        anchors.bottom: stationBottomBar.top
        color: "transparent"
        MouseArea{
            anchors.fill: parent
            onClicked: {}
        }
        BusyIndicator {
            id: indicator
            anchors.centerIn: parent
            platformStyle: BusyIndicatorStyle { size: "large" }
            running: true
        }
    }
    FriendsFollowNumber{
        id:friendFollowNumberPage
    }
    Component.onCompleted: {
        context.getSpecifyFriendStation(friendId);
    }
}
