import QtQuick 1.0
import com.nokia.meego 1.0

Rectangle {
    id:startUpScreen
    width: parent.width
    height: parent.height

    property bool fbclicked: false
    property bool componentCreated: false
    property variant facebookQml
    property variant component
    property alias errorDialog: myDialog

    function facebookClicked(){
        if(fbclicked==false){
            fbclicked = true;
            if(componentCreated==false){
                componentCreated=true;
                component = Qt.createComponent("FaceBookLogin.qml");
                if(component.status == Component.Ready){
                    facebookQml = component.createObject(startUpScreen);
                    facebookQml.state="ShowUp"
                }
            }else{
                startUpScreen.facebookQml.state = "ShowUp";
            }
        }
    }
    Image {
        id: bg
        source: "../image/home_bg.png"
        anchors.fill: parent
    }

    Image {
        id: homeLogo
        source: "../image/logo.png"
        anchors.top:parent.top
        anchors.topMargin: 40
    }

    Image {
        id: homeLine
        source: "../image/home_line.png"
        width: parent.width
        height: homeLine.sourceSize.height
        anchors.top:homeLogo.bottom
        anchors.topMargin: 40
    }

    Rectangle{
        id:btnBg
        width: parent.width
        anchors.top:homeLine.bottom
        anchors.bottom: parent.bottom
        color: "black"

        // fbBtn
        Rectangle {
            id: fbBtn
            width: fbBtnBg.width
            height: fbBtnBg.height
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: parent.top
            anchors.topMargin: 40
            color: "transparent"
            BorderImage {
                id: fbBtnBg
                source: "../image/facebook.png"
                width: 375; height: sourceSize.height*1.1
                border.left: 7; border.top: 7
                border.right: 7; border.bottom: 7
            }

            Text {
                id: fbBtnLabel
                text: qsTr("Sign in with") + " Facebook"
                anchors.verticalCenter: fbBtnBg.verticalCenter
                anchors.left:fbBtnBg.left
                anchors.leftMargin: 70
                width: parent.width-70
                elide: Text.ElideRight
                font.bold: true
                color: "white"
                font.pixelSize: 22
            }

            MouseArea{
                anchors.fill: parent
                onClicked: {
                    mainPage.faceBookCreateFrom="login";
                    facebookClicked();
                }
            }
        }

        // twBtn
        Rectangle{
            id: twBtn
            width: twBtnBg.width
            height: twBtnBg.height
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: fbBtn.bottom
            anchors.topMargin: 30
            color: "transparent"
            BorderImage {
                id: twBtnBg
                source: "../image/twtter.png"
                width: 375; height: sourceSize.height*1.1
                border.left: 7; border.top: 7
                border.right: 7; border.bottom: 7
            }

            Text {
                id: twBtnLabel
                text: qsTr("Sign in with") + " Twitter"
                anchors.verticalCenter: twBtnBg.verticalCenter
                anchors.left:twBtnBg.left
                anchors.leftMargin: 70
                width: parent.width-70
                elide: Text.ElideRight
                font.bold: true
                color: "white"
                font.pixelSize: 22
            }
            MouseArea{
                anchors.fill: parent
                onClicked: {
                    mainPage.twitterLoginFrom="login";
                    pageStack.push(Qt.resolvedUrl("TwitterLogin.qml"));
                }
            }
        }

        // stBtn
        Rectangle{
            id: stBtn
            width: stBtnBg.width
            height: stBtnBg.height
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: twBtn.bottom
            anchors.topMargin: 30
            color: "transparent"
            BorderImage {
                id: stBtnBg
                source: "../image/soundtraker.png"
                width: 375; height: sourceSize.height*1.1
                border.left: 7; border.top: 7
                border.right: 7; border.bottom: 7
            }
            Text {
                id: stBtnLabel
                text: qsTr("Sign in with") + " Soundtracker"
                anchors.verticalCenter: stBtnBg.verticalCenter
                anchors.left:stBtnBg.left
                anchors.leftMargin: 70
                width: parent.width -70
                elide: Text.ElideRight
                font.bold: true
                color: "white"
                font.pixelSize: 22
            }
            MouseArea{
                anchors.fill: parent
                onClicked: {
                    mainPage.stLoginFrom = "login";
                    pageStack.push(Qt.resolvedUrl("SoundTrackerLogin.qml"));
                }
            }
        }

        Item {
            id: item
            width: parent.width
            height: 50
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: stBtn.bottom
            anchors.topMargin: 20
            Row {
                anchors.centerIn: parent
                // stTermsOfService
                Text {
                    id: stTermsOfService
                    width: item.width / 2 - 2
                    height: item.height
                    font.pixelSize: 22
                    color: "white"
                    font.underline: true
                    wrapMode: Text.WordWrap
                    textFormat: Text.RichText
                    text: qsTr("Terms of Service")
                    horizontalAlignment: Text.AlignRight
                    MouseArea {
                        anchors.fill: parent
                        onClicked:  pageStack.push(Qt.resolvedUrl("Tos.qml"))
                    }
                }

                Text {
                    font.pixelSize: 24
                    color: "white"
                    text: " | "
                    horizontalAlignment: Text.AlignHCenter
                }

                // stPrivacyPolicy
                Text {
                    id: stPrivacyPolicy
                    width: item.width / 2 - 2
                    height: item.height
                    font.pixelSize: 22
                    color: "white"
                    font.underline: true
                    wrapMode: Text.WordWrap
                    textFormat: Text.RichText
                    horizontalAlignment: Text.AlignLeft
                    text:  qsTr("Privacy Policy")
                    MouseArea {
                        anchors.fill: parent
                        onClicked:  pageStack.push(Qt.resolvedUrl("PrivacyPolicy.qml"))
                    }
                }
            }
        }
    }

    StationPlayerPopDialog {
        id: myDialog
        dialogAccept: qsTr("Ok")
        dialogTitle: qsTr("Login failed")
        dialogContent: qsTr("Login failed. Please click the button or any space to close this page and try again.")
        onAccepted: {
            fbclicked = true;
            startUpScreen.facebookQml.state = "HideDown";
            startUpScreen.facebookQml.destroy();
            fbclicked = false;
            componentCreated = false;
        }
    }
}
