import QtQuick 1.0
import com.nokia.meego 1.0
import "CommonUtil.js" as Util
import RoundedImage 1.0

Item {
    id: stationCommentsPage
    property string objectId;

    width: parent.width
    height: parent.height

    Connections {
        target: context
        onGetStationCommentsFinished: {
            indicator.running = false;
            indicator.visible = false;
            if (type === 0) {
                messageList.model = stationCommentsModel;
            }
        }
        onRefreshStationCommentsFinished: {
            indicator.running = false;
            indicator.visible = false;
            if (type === 0) {
                messageList.model = stationCommentsModel;
                messageList.currentIndex = messageList.count - 1;
            } else if (type === 1) {
                addStationCommentDialog.open();
            }
        }
    }

    MouseArea {
        anchors.fill: parent
        onClicked: {
            messageInput.closeSoftwareInputPanel();
            messageInput.focus = false;
        }
    }

    Image {
        id: backgroudImg
        width: parent.width
        height: parent.height
        source: "../image/home_bg.png"
    }

    Item {
        id: commentsTopBar
        width: parent.width
        height: commentsTopBarBg.sourceSize.height
        Image {
            id: commentsTopBarBg
            anchors.fill: parent
            source: "../image/top_bar.png"
        }
        Text {
            width: parent.width
            anchors.left: parent.left
            anchors.leftMargin: 20
            anchors.verticalCenter: parent.verticalCenter
            font.pixelSize: 24
            wrapMode: Text.WordWrap
            elide: Text.ElideRight
            color: "white"
            text: qsTr("Comments")
        }
    }

    ListView {
        id: messageList
        width: parent.width
        anchors.top: commentsTopBar.bottom
        anchors.bottom: inputArea.top
        anchors.topMargin: 10
        anchors.bottomMargin: 10
        clip: true
        spacing: 15
//        model: stationCommentsModel
        delegate: messageListDelegate
        highlightMoveDuration: 500
        MouseArea {
            anchors.fill: parent
            onClicked: {
                messageInput.closeSoftwareInputPanel();
                messageInput.focus = false;
            }
        }
    }

    Component {
        id: messageListDelegate
        Item {
            width: ListView.view.width
            height: (name.height + createTime.height + ownerComment.height) < 100 ? 100 : name.height + createTime.height + ownerComment.height
            Item {
                id: ownerIcon
                anchors.left: parent.left
                anchors.leftMargin: 15
                width: 100;
                height: width
                RoundedImage {
                    id: defaultImg
                    width: parent.width - 2
                    height: width
                    anchors.centerIn: parent
                    source: Util.getRandomDefaultThumb();
                    engine: declarativeEngine
                }
                RoundedImage {
                    id: image
                    visible: false
                    width: parent.width - 2
                    height: width
                    anchors.centerIn: parent
                    source: ownerImage
                    engine: declarativeEngine
                }
            }
            Text {
                id: name
                anchors.top: parent.top
                anchors.left: ownerIcon.right
                anchors.leftMargin: 15
                anchors.rightMargin: 15
                anchors.right: parent.right
                elide: Text.ElideRight
                color: "white"
                font.pixelSize: 20
                text: ownerName
            }
            Text {
                id: createTime
                anchors.left: ownerIcon.right
                anchors.leftMargin: 15
                anchors.top: name.bottom
                color: "white"
                font.pixelSize: 16
                text: createTs
            }
            Text {
                id: ownerComment
                anchors.left: ownerIcon.right
                anchors.leftMargin: 15
                anchors.rightMargin: 15
                anchors.right: parent.right
                anchors.top: createTime.bottom
                color: "white"
                font.pixelSize: 16
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                text: comment
            }
            states: [
                 State {
                     name: "Show"; when: image.imageStatus == RoundedImage.Ready
                     PropertyChanges { target: image; visible: true }
                     PropertyChanges {target: defaultImg; visible: false}
                 }
             ]
        }
    }
    Item {
        id: inputArea
        width: parent.width
        height: inputAreaBg.sourceSize.height
        anchors.bottom: {
            if (playbackProgressBarArea.visible == false) {
                return stationBottomBar.top;
            } else {
                return playbackProgressBarArea.top;
            }
        }
        Image {
            id: inputAreaBg
            anchors.fill: parent
            source: "../image/search_bg.png"
        }
        Image {
            id: inputBox
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.leftMargin: 10
            anchors.rightMargin: 10
            anchors.verticalCenter: parent.verticalCenter
            anchors.bottomMargin: 10
            source: "../image/search.png"
            TextInput {
                id: messageInput
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.rightMargin: 50
                anchors.leftMargin: 15
                anchors.verticalCenter: parent.verticalCenter
                font.pixelSize: 20
                color: "black"
                onActiveFocusChanged: {
                    if (messageInput.activeFocus) {
                        playbackProgressBarArea.visible = false;
                        stationBottomBar.visible = false;
                    } else if (!messageInput.activeFocus) {
                        if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                            playbackProgressBarArea.visible = true;
                        }
                        stationBottomBar.visible = true;
                    }
                }
            }
            Text {
                id: messageDefaultText
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.rightMargin: 50
                anchors.leftMargin: 15
                anchors.verticalCenter: parent.verticalCenter
                font.pixelSize: 20
                color: "gray"
                wrapMode: Text.WordWrap
                elide: Text.ElideRight
                text: qsTr("Write comment")
                visible: {
                    if (messageInput.text.length > 0 || messageInput.activeFocus) {
                        return false;
                    } else {
                        return true;
                    }
                }
            }
        }
        Image {
            id: icon
            anchors.right: parent.right
            anchors.rightMargin: 20
            anchors.verticalCenter: parent.verticalCenter
            source: "../image/message_icon.png"
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if (Util.trim(messageInput.text) !== "") {
                        indicator.running = true;
                        indicator.visible = true;
                        context.addStationComment(stationCommentsPage.objectId, messageInput.text);
                        messageInput.text = "";
                        messageInput.closeSoftwareInputPanel();
                        messageInput.focus = false;
                    }
                }
            }
        }
    }

    BusyIndicator {
        id: indicator
        anchors.centerIn: messageList
        platformStyle: BusyIndicatorStyle { size: "large" }
        running: true
    }
    Item {
        id: playbackProgressBarArea
        width: parent.width
        height: playbackProgressBarAreaBg.sourceSize.height
        anchors.bottom: stationBottomBar.top
        visible: {
            if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                return true;
            } else {
                return false;
            }
        }
        Image {
            id: playbackProgressBarAreaBg
            source: "../image/music_play_bg.png"
        }
        MediaPlaybackProgressBar {
            id: mediaPlaybackProgressBar
            anchors.verticalCenter: parent.verticalCenter
            value: context.currentPlayingPosition
            maximum: context.currentPlayingDuration
            leftmum: maximum - value
        }
    }
    StationsBottomBar {
        id: stationBottomBar
        anchors.bottom: parent.bottom
        onVisibleChanged: {
            if (playbackProgressBarArea.visible == true) {
                if (stationBottomBar.visible == true) {;
                    inputArea.anchors.bottom = playbackProgressBarArea.top
                }
            } else if (playbackProgressBarArea.visible == false) {
                if (stationBottomBar.visible == true) {
                    inputArea.anchors.bottom = stationBottomBar.top;
                } else if (stationBottomBar.visible == false) {
                    inputArea.anchors.bottom = stationCommentsPage.bottom;
                }
            }
        }
        onGoBack: {
            pageStack.pop();
            messageInput.closeSoftwareInputPanel();
        }
    }

    StationPlayerPopDialog {
        id: addStationCommentDialog
        dialogAccept: qsTr("Ok")
        dialogTitle: qsTr("Add Comments Error")
        dialogContent: qsTr("Server or network error, please try it later!")
    }

    Component.onCompleted: {
        context.getStationComments(stationCommentsPage.objectId);
    }
}
