import QtQuick 1.0
import "CommonUtil.js" as Util

Item {
    id: showStationsByList
    property alias listViewModel: listView.model
    width: parent.width
    height: parent.height

    ListView {
        id: listView
        width: parent.width
        height: parent.height
        spacing: 15
        clip: true
        delegate: listViewDelegate
    }
    Component {
        id: listViewDelegate
        Item {
            width: ListView.view.width
            height: 100

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    context.getNextSong(stationId, stationName);
                    context.stationMarkPlay(stationId); //Added by Camilo
                    pageStack.push(Qt.resolvedUrl("StationPlayer.qml"));
                }
            }

            Item {
                id: stationIcon
                anchors.left: parent.left
                anchors.leftMargin: 15
                width: 100
                height: width
                smooth: true
                Image {
                    id: defaultImg
                    width: parent.width - 2
                    height: width
                    anchors.centerIn: parent
                    source: Util.getRandomDefaultThumb();
                }
                Image {
                    id: stationImage
                    scale: 0.0
                    width: parent.width - 2
                    height: width
                    anchors.centerIn: parent
                    source: image
                }
            }
            Text {
                id: title
                anchors.top: parent.top
                anchors.left: stationIcon.right
                anchors.leftMargin: 15
                anchors.right: parent.right
                elide: Text.ElideRight
                color: "white"
                font.pixelSize: 20
                text: stationName
            }
            Text {
                id: location
                anchors.left: stationIcon.right
                anchors.leftMargin: 15
                anchors.top: title.bottom
                color: "white"
                font.pixelSize: 16
                elide: Text.ElideRight
                text: {
                    if (ownerLocation !== "") {
                        return qsTr("Location:") + " " + ownerLocation;
                    } else {
                        return qsTr("Location:") + " " + qsTr("Unknown");
                    }
                }
            }
            Text {
                id: lastPlayedTime
                anchors.left: stationIcon.right
                anchors.leftMargin: 15
                anchors.top: location.bottom
                color: "white"
                font.pixelSize: 16
                text: {
                    var lpt = lastPlayedTs.split("-");
                    var flag = lpt[1];
                    var nums = lpt[0];
                    if (flag == "s") {
                        return qsTr("Last played:") + " " + nums + " " + qsTr("seconds ago");
                    } else if (flag == "m") {
                        return qsTr("Last played:") + " " + nums + " " + qsTr("minutes ago");
                    } else if (flag == "h") {
                        return qsTr("Last played:") + " " + nums + " " + qsTr("hours ago");
                    } else if (flag == "d") {
                        return qsTr("Last played:") + " " + nums + " " + qsTr("days ago");
                    } else if (flag == "y") {
                        return qsTr("Last played:") + " " + nums + " " + qsTr("years ago");
                    }
                }
            }
            Text {
                id: createdTime
                anchors.left: stationIcon.right
                anchors.leftMargin: 15
                anchors.top: lastPlayedTime.bottom
                color: "white"
                font.pixelSize: 16
                text: {
                    var lpt = createdTs.split("-");
                    var flag = lpt[1];
                    var nums = lpt[0];
                    if (flag == "s") {
                        return qsTr("Created:") + " " + nums + " " + qsTr("seconds ago");
                    } else if (flag == "m") {
                        return qsTr("Created:") + " " + nums + " " + qsTr("minutes ago");
                    } else if (flag == "h") {
                        return qsTr("Created:") + " " + nums + " " + qsTr("hours ago");
                    } else if (flag == "d") {
                        return qsTr("Created:") + " " + nums + " " + qsTr("days ago");
                    } else if (flag == "y") {
                        return qsTr("Created:") + " " + nums + " " + qsTr("years ago");
                    }
                }
            }
            states: [
                State {
                    name: "Show"; when: stationImage.status == Image.Ready
                    PropertyChanges { target: stationImage; scale: 1 }
                    PropertyChanges {target: defaultImg; visible: false}
                }
            ]

            transitions: [
                Transition {
                    NumberAnimation {
                        properties: "scale"; duration: 500; easing.type: Easing.InOutQuad
                    }
                }
            ]
        }
    }
}
