import QtQuick 1.0
import com.nokia.meego 1.0
import "CommonUtil.js" as Util
import RoundedImage 1.0

Item {
    id: stationListener
    property string stationId: ""
    property string stationName: ""
    property int selectIndex: 0

    width: parent.width
    height: parent.height

    Connections {
        target: context
        onGetCurrentStationListenersFinished: {
            indicator.running = false;
            indicator.visible = false;
            if (type === 0) {
                listView.model = listenersModel;
            }
        }
    }

    Image {
        id: backgroudImg
        width: parent.width
        height: parent.height
        source: "../image/home_bg.png"
    }

    Image {
        id: listenerTopBarBg
        width: parent.width
        source: "../image/top_bar.png"
    }

    Text {
        id: listenerTopBarText
        width: parent.width - 20
        anchors.left: parent.left
        anchors.leftMargin: 20
        anchors.verticalCenter: listenerTopBarBg.verticalCenter
        font.pixelSize: 24
        elide: Text.ElideRight
        color: "white"
        text: qsTr("Listeners of ") + "\"" + stationListener.stationName + "\""
    }
    Item {
        id: selectionArea
        width: parent.width
        height: listeningBg.sourceSize.height
        anchors.top: listenerTopBarBg.bottom
        anchors.topMargin: 20
        Image {
            id: listeningBg
            anchors.right: parent.right
            anchors.rightMargin: parent.width / 2
            source: "../image/select_a01.png"
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if (stationListener.selectIndex === 1) {
                        indicator.running = true;
                        indicator.visible = true;
                        listeningBg.source = "../image/select_a01.png"
                        historyListener.source = "../image/select_a02.png"
                        stationListener.selectIndex = 0;
                        context.getCurrentStationListeners(stationListener.stationId, "online");
                    }
                }
            }
        }
        Image {
            id: historyListener
            anchors.left: listeningBg.right
            source: "../image/select_a02.png"
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if (stationListener.selectIndex === 0 && indicator.running === false) {
                        indicator.running = true;
                        indicator.visible = true;
                        historyListener.source = "../image/select_b02.png"
                        listeningBg.source = "../image/select_b01.png"
                        stationListener.selectIndex = 1;
                        context.getCurrentStationListeners(stationListener.stationId, "offline");
                    }
                }
            }
        }
        Text {
            width: listeningBg.width - 10
            anchors.left: listeningBg.left
            anchors.verticalCenter: listeningBg.verticalCenter
            elide: Text.ElideRight
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            font.pixelSize: 18
            font.bold: true
            color: "white"
            text: qsTr("Now listening")
        }
        Text {
            width: historyListener.width - 10
            anchors.left: historyListener.left
            anchors.verticalCenter: historyListener.verticalCenter
            elide: Text.ElideRight
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            font.pixelSize: 18
            font.bold: true
            color: "white"
            text: qsTr("History")
        }
    }

    ListView {
        id: listView
        width: parent.width
        anchors.top: selectionArea.bottom
        anchors.bottom: listenersBottomBar.top
        anchors.topMargin: 20
        anchors.bottomMargin: 10
        spacing: 15
        clip: true
//        model: listenersModel
        delegate: Component {
            Item {
                width: ListView.view.width
                height: 100
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        pageStack.push(Qt.resolvedUrl("SpecifyFriendStations.qml"), {
                                           friendName:listenerName,
                                           friendId:listenerId,
                                           friendLocation:location,
                                           friendPhoto:pictureUrl,
                                           followersNum:numFollowers,
                                           followingNum:numFollowing
                                       });
                    }
                }
                Item {
                    id: listenerIcon
                    anchors.left: parent.left
                    anchors.leftMargin: 15
                    width: 100
                    height: width
                    RoundedImage {
                        id: defaultImg
                        width: parent.width - 2
                        height: width
                        anchors.centerIn: parent
                        source: Util.getRandomDefaultThumb();
                        engine: declarativeEngine
                    }
                    RoundedImage {
                        id: listenerImage
                        visible: false
                        width: parent.width - 2
                        height: width
                        anchors.centerIn: parent
                        source: pictureUrl
                        engine: declarativeEngine
                    }
                }
                Text {
                    id: name
                    anchors.top: parent.top
                    anchors.topMargin: 20
                    anchors.left: listenerIcon.right
                    anchors.leftMargin: 15
                    anchors.right: parent.right
                    elide: Text.ElideRight
                    color: "white"
                    font.pixelSize: 20
                    text: listenerName
                }
                states: [
                     State {
                         name: "Show"; when: listenerImage.imageStatus == RoundedImage.Ready
                         PropertyChanges { target: listenerImage; visible: true }
                         PropertyChanges {target: defaultImg; visible: false}
                     }
                 ]
            }
        }
    }

    BusyIndicator {
        id: indicator
        anchors.centerIn: stationListener
        platformStyle: BusyIndicatorStyle { size: "large" }
        running: true
    }

    StationsBottomBar {
        id: listenersBottomBar
        anchors.bottom: parent.bottom
        onGoBack: {
            pageStack.pop();
        }
    }

    Item {
        id: playbackProgressBarArea
        width: parent.width
        height: playbackProgressBarAreaBg.sourceSize.height
        anchors.bottom: listenersBottomBar.top
        visible: {
            if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                return true;
            } else {
                return false;
            }
        }
        Image {
            id: playbackProgressBarAreaBg
            source: "../image/music_play_bg.png"
        }
        MediaPlaybackProgressBar {
            id: mediaPlaybackProgressBar
            anchors.verticalCenter: parent.verticalCenter
            value: context.currentPlayingPosition
            maximum: context.currentPlayingDuration
            leftmum: maximum - value
        }
    }

    Component.onCompleted: {
        context.getCurrentStationListeners(stationListener.stationId, "online");
    }
}
