import QtQuick 1.0
import com.nokia.meego 1.0


Item {
    id: stationPlayer
    width: parent.width
    height: parent.height
    Connections {
        target: context
        onGetNextSongFinished: {
            if (type === 0) {
                context.playCurrentSong();
            } else if (type === 1) {
                serverErrorDialog.dialogTitle = qsTr("Get Station Error");
                serverErrorDialog.dialogContent = qsTr("Server or network error, please try it later!");
                serverErrorDialog.open();
            }
        }
        onCreateStationFinished: {
            if (type === 0) {
                context.playCurrentSong();
                context.getMyStation();
                context.stationMarkPlay(context.currentPlayingStationId);
            } else if (type === 1) {
                serverErrorDialog.dialogTitle = qsTr("Create Station Error");
                serverErrorDialog.dialogContent = qsTr("Server or network error, please try it later!");
                serverErrorDialog.open();
            }
        }
        onAddArtistFinished: {
            if (type === 0) {
                context.playCurrentSong();
            } else if (type === 1) {
                serverErrorDialog.dialogTitle = qsTr("Add Artist Error");
                serverErrorDialog.dialogContent = qsTr("Server or network error, please try it later!");
                serverErrorDialog.open();
            }
        }
        onCurrentSongNameChanged: {
            context.currentLyric="";
        }
        onOpenSharedStationFinished: {
            if (type === 1) {
                serverErrorDialog.dialogTitle = qsTr("Open Shared Station Error");
                serverErrorDialog.dialogContent = qsTr("Server or network error, please try it later!");
                serverErrorDialog.open();
            }
        }
        onMediaPlayerError: {
            if (error !== 0) {
                pageStack.pop();
            }
        }
        onMarkFavoriteSongFinished:{
            if(type===0) {
                markSongDialog.open();
            }else {
                markSongErrorDialog.open()
            }
        }
        onRemoveSongFinished: {
            selectionDialog.selectedIndex = -1;
            if (type === 0) {
                context.playNextUpSong();
            } else if(type === 1){
                removeFailedDialog.dialogTitle = qsTr("Delete Track Failed");
                removeFailedDialog.dialogContent = qsTr("Server or network error, please try it later!");
                removeFailedDialog.open();
            }
        }
        onRemoveArtistFinised: {
            selectionDialog.selectedIndex = -1;
            if (type === 0) {
                context.playNextUpSong();
            } else if(type === 1){
                removeFailedDialog.dialogTitle = qsTr("Delete Artist Failed");
                removeFailedDialog.dialogContent = qsTr("Server or network error, please try it later!");
                removeFailedDialog.open();
            }
        }
        onNoNextUpTrackToPlay: {
            serverErrorDialog.dialogTitle = qsTr("Play Next Up Song Error");
            serverErrorDialog.dialogContent = qsTr("Next up song is not available, you can change to other stations and try this later!");
            serverErrorDialog.open();
        }
        onRemoveStationFinished: {
            selectionDialog.selectedIndex = -1;
            if (type === 0) {
                pageStack.pop()
                console.log("stop!!!")
                context.stopMediaPlayer();
            } else if(type === 1){
                removeFailedDialog.dialogTitle = qsTr("Delete Station Failed");
                removeFailedDialog.dialogContent = qsTr("Please try it later!");
                removeFailedDialog.open();
            }
        }
    }

    Image {
        id: backgroudImg
        width: parent.width
        height: parent.height
        source: "../image/home_bg.png"
    }

    StationPlayerTopBar {
        id: playerTopBar
        anchors.top: parent.top
        stationNameText: context.currentPlayingStationName
    }
    Item {
        id: searchArea
        anchors.top: playerTopBar.bottom
        width: parent.width
        height: searchAreaBg.sourceSize.height
        Image {
            id: searchAreaBg
            anchors.fill: parent
            source: "../image/search_bg.png"
        }
        Image {
            id: searchBox
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.leftMargin: 10
            anchors.rightMargin: 10
            anchors.verticalCenter: parent.verticalCenter
            anchors.bottomMargin: 10
            source: "../image/search.png"
            Text {
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.leftMargin: 30
                anchors.rightMargin: 50
                anchors.verticalCenter: parent.verticalCenter
                font.pixelSize: 20
                elide: Text.ElideRight
                text: qsTr("Search for Artist to add to the Station")
                color: "gray"
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    pageStack.push(Qt.resolvedUrl("SearchArtistPage.qml"), {searchPurpose: "ADDARTIST", stationId: context.currentPlayingStationId});
                }
            }
        }
        Image {
            id: icon
            anchors.right: parent.right
            anchors.rightMargin: 20
            anchors.verticalCenter: parent.verticalCenter
            source: "../image/icon_a.png"
        }
    }

    Flickable {
        id: flickableArea
        width: parent.width
        anchors.top: searchArea.bottom
        anchors.bottom: playerBottomBar.top
        contentWidth: parent.width
        contentHeight: songArea.height + controlToolArea.height + playArea.height + functionAreaView.height
        boundsBehavior: Flickable.StopAtBounds
        clip: true
        Item {
            id: songArea
            width: parent.width
            anchors.top: parent.top
            height: playingArtWorkImage.height + playingSongArtist.height + playingSongName.height + 20
            Item {
                id: playingArea
                width: 300
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.topMargin: 10
                anchors.leftMargin: 10
                Image {
                    id: playingArtWorkImage
                    width: 300
                    height: 300
                    x: 0
                    y: 0
                    source: {
                        if (context.currentSongArtWorkUrl !== "") {
                            var albumURL = context.currentSongArtWorkUrl;
                            var index = albumURL.lastIndexOf("/");
                            var tempURL = albumURL.substring(0, index + 1);
                            albumURL = tempURL + "a.jpeg";
//                            console.log(albumURL);
                            return albumURL;
                        } else {
                            return "";
                        }
                    }
                    onStatusChanged: {
                        if (status == Image.Error) {
                            playingArtWorkImage.source = context.currentSongArtWorkUrl;
                        }
                    }

                    MouseArea {
                        anchors.fill: parent
                        drag.target: playingArtWorkImage
                        drag.axis: Drag.XAxis
                        drag.minimumX: 0
                        drag.maximumX: nextPlayingArtWorkImage.width + 20
                        onReleased: {
                            if (playingArtWorkImage.x > nextPlayingArtWorkImage.width / 2) {
                                playingArtWorkImage.x = 0;
                                pageStack.push(Qt.resolvedUrl("TrackHistoryViewer.qml"));
                            } else {
                                playingArtWorkImage.x = 0;
                            }
                        }
                    }
                }
                Text {
                    id: playingSongArtist
                    width: playingArtWorkImage.width
                    anchors.top: playingArtWorkImage.bottom
                    anchors.topMargin: 10
                    color: "white"
                    font.pixelSize: 20
                    elide: Text.ElideRight
                    text: context.currentSongArtist
                }
                Text {
                    id: playingSongName
                    width: playingArtWorkImage.width
                    anchors.top: playingSongArtist.bottom
                    color: "white"
                    font.pixelSize: 20
                    elide: Text.ElideRight
                    text: context.currentSongName
                }
            }
            Item {
                id: nextPlayingArea
                width: 150
                x: parent.width - 160
                y: playingArea.y
                anchors.rightMargin: 10
                anchors.topMargin: 10
                visible: {
                    if (context.nextUpSong) {
                        return true
                    } else {
                        return false;
                    }
                }

                Image {
                    id: nextPlayingArtWorkImage
                    width: 150
                    height: 150
                    source: context.nextUpSongArtWorkUrl
                    MouseArea {
                        anchors.fill: parent
                        drag.target: nextPlayingArea
                        drag.axis: Drag.XAxis
                        drag.minimumX: 0
                        drag.maximumX: songArea.width - nextPlayingArea.width
                        onReleased: {
                            if (nextPlayingArea.x > playingArea.x + playingArea.width - nextPlayingArea.width) {
                                nextPlayingArea.x = songArea.width - 160;
                            } else {
                                context.playNextUpSong();
                                nextPlayingArea.x = songArea.width - 160;
                            }
                        }
                    }
                }
                Text {
                    id: nextUp
                    width: nextPlayingArtWorkImage.width
                    anchors.top: nextPlayingArtWorkImage.bottom
                    anchors.topMargin: 10
                    color: "white"
                    font.pixelSize: 16
                    elide: Text.ElideRight
                    text: qsTr("Next Up")
                }
                Text {
                    id: nextPlayingSongName
                    width: nextPlayingArtWorkImage.width
                    anchors.top: nextUp.bottom
                    color: "white"
                    font.pixelSize: 16
                    wrapMode: Text.WordWrap
//                    text: context.nextUpSongName
                    text: context.nextUpSongArtist
                }
            }
        }

        Item {
            id: controlToolArea
            width: parent.width
            height: 80
            anchors.top: songArea.bottom
            Item {
                width: history.sourceSize.width
                height: parent.height
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.verticalCenter: parent.verticalCenter
                Image {
                    id: history
                    anchors.centerIn: parent
                    source: "../image/time.png"
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        pageStack.push(Qt.resolvedUrl("TrackHistoryViewer.qml"));
                    }
                }
            }
            Item {
                width: playAndPause.sourceSize.width
                height: parent.height
                anchors.centerIn: parent
                anchors.verticalCenter: parent.verticalCenter
                Image {
                    id: playAndPause
                    anchors.centerIn: parent
                    source: {
                        if (context.mediaPlayerState == "playing") {
                            return "../image/pause.png"
                        } else {
                            return "../image/play.png"
                        }
                    }
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        if (context.mediaPlayerState == "playing") {
                            context.mediaPlayerPause();
                        } else {
                            context.mediaPlayerResume();
                        }
                    }
                }
            }
            Item {
                width: controllerNext.sourceSize.width
                height: parent.height
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.verticalCenter: parent.verticalCenter
                Image {
                    id: controllerNext
                    anchors.centerIn: parent
                    source: "../image/next.png"
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        if (context.nextUpSongId !== "") {
                            context.playNextUpSong();
                        } else {
                        }
                    }
                }
            }
        }
        Item {
            id: playArea
            width: parent.width
            height: 60
            anchors.top: controlToolArea.bottom
            MediaPlaybackProgressBar {
                id: mediaPlaybackProgressBar
                anchors.centerIn: parent
                isPlayerPage: true
                value: context.currentPlayingPosition
                maximum: context.currentPlayingDuration
                leftmum: maximum - value
            }
        }

        ListView {
            id: functionAreaView
            width: parent.width
            height: 300
            spacing: 10
            orientation:ListView.Vertical
            anchors.top: playArea.bottom
            interactive: false
            model: functionAreaModel
            delegate: functionAreaDelegate
        }

        ListModel {
            id: functionAreaModel
            ListElement {
                name: "View who's listening"
                portrait:"../image/view-listening.png"
                switchUI:"StationListenersPage.qml"
                elementEnabled:true
            }
            ListElement {
                name: "Lyrics"
                portrait:"../image/lyrics.png"
                switchUI:"Lyrics.qml"
                elementEnabled:true
            }
            ListElement {
                name: "Comment"
                portrait:"../image/comment.png"
                switchUI:"StationCommentsPage.qml"
                elementEnabled:true
            }
            ListElement {
                name: "View Artist"
                portrait:"../image/view-aritst.png"
                switchUI:"ArtistInfoViewer.qml"
                elementEnabled:true
            }
        }

        Component {
            id: functionAreaDelegate
            Item
            {
                width: ListView.view.width
                height: 60
                //enabled: elementEnabled
                Image {
                    id: icon
                    source: portrait
                    anchors.left: parent.left
                    anchors.leftMargin: 10
                    anchors.verticalCenter: parent.verticalCenter
                }
                Text {
                    id: title
                    anchors.top: parent.top
                    anchors.left: icon.right
                    anchors.leftMargin: 10
                    anchors.right: gotoIcon.left
                    anchors.rightMargin: 10
                    color: "white"
                    font.pixelSize: 16
                    wrapMode: Text.WordWrap
                    elide: Text.ElideRight
                    text: {
                        if (name === "View who's listening") {
                            return qsTr("View who's listening");
                        } else if (name === "Lyrics") {
                            return qsTr("Lyrics");
                        } else if (name === "Comment") {
                            return qsTr("Comment");
                        } else if (name === "View Artist") {
                            return qsTr("View Artist");
                        }
                    }
                }
                Text {
                    id: contents
                    anchors.top: title.bottom
                    anchors.left: icon.right
                    anchors.leftMargin: 10
                    anchors.right: gotoIcon.left
                    anchors.rightMargin: 10
                    text: { // need to finished each value
                        if (name === "View who's listening") {
                            var lpt = context.lastListeningTs.split("-");
                            var flag = lpt[1];
                            var nums = lpt[0];
                            if (flag == "s") {
                                return qsTr("Last listened:") + " " + nums + " " + qsTr("seconds ago");
                            } else if (flag == "m") {
                                return qsTr("Last listened:") + " " + nums + " " + qsTr("minutes ago");
                            } else if (flag == "h") {
                                return qsTr("Last listened:") + " " + nums + " " + qsTr("hours ago");
                            } else if (flag == "d") {
                                return qsTr("Last listened:") + " " + nums + " " + qsTr("days ago");
                            } else if (flag == "y") {
                                return qsTr("Last listened:") + " " + nums + " " + qsTr("years ago");
                            }
                        } else if (name === "Lyrics") {
                            return context.currentSongName;
                        } else if (name === "Comment") {
                            return context.currentPlayingStationComments + " " + qsTr("comments");
                        } else if (name === "View Artist") {
                            return context.currentSongArtist;
                        }
                    }
                    color: "gray"
                    font.pixelSize: 16
                    wrapMode: Text.WordWrap
                    elide: Text.ElideRight
                }

                Image {
                    id: gotoIcon
                    anchors.right: parent.right
                    anchors.rightMargin: 10
                    anchors.verticalCenter: parent.verticalCenter
                    source: "../image/arrow_b.png"
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        if (name === "Comment") {
                            pageStack.push(Qt.resolvedUrl(switchUI), {objectId: context.currentPlayingStationId});
                        } else if(name === "View who's listening") {
                            pageStack.push(Qt.resolvedUrl(switchUI), {
                                               stationId: context.currentPlayingStationId,
                                               stationName: context.currentPlayingStationName
                                           });
                        } else {
                            pageStack.push(Qt.resolvedUrl(switchUI));
                        }
                    }
                }
            }
        }
    }

    Rectangle {
        id: mask
        width: parent.width
        height: parent.height - playerBottomBar.height
        color: "black"
        opacity: 0.7
        visible: context.mediaPlayerLoading
        MouseArea {
            anchors.fill: parent
            onClicked: {
            }
        }
    }

    BusyIndicator {
        id: indicator
        anchors.centerIn: parent
        platformStyle: BusyIndicatorStyle { size: "large" ;__invertedString: "inverted" }
        running: context.mediaPlayerLoading
        visible: context.mediaPlayerLoading
    }
    /**
     * developer need implemente the each of the function
    */
    StationPlayerBottomBar {
        id: playerBottomBar
        width: parent.width
        anchors.bottom: parent.bottom
        //Go back to history
        onGoBack: {
            pageStack.pop();
        }
        // Open Share Page
        onShareTo: {
            pageStack.push(Qt.resolvedUrl("ShareStation.qml"));
        }
        // marked
        onMark: {
            if(context.currentSongId!=="")
            {
                context.markFavoriteSong(context.currentSongId);
            }
        }
        // Go to edit stationName page
        onEdit: {
            if (context.isFromMyStation) {
                pageStack.push(Qt.resolvedUrl("EditStationName.qml"));
            }
        }
        // Go to delete page
        onDel: {
            if (context.isFromMyStation && context.currentSongId !== "") {
                selectionDialog.open();
            }
        }
    }
    StationPlayerPopDialog {
        dialogAccept: qsTr("Ok")
        id: serverErrorDialog
        onAccepted: {
            pageStack.pop();
        }
    }
    StationPlayerPopDialog {
        dialogAccept: qsTr("Ok")
        id: removeFailedDialog
    }
    StationPlayerDeleteDialog {
        id: selectionDialog
        onAccepted: {
            if (selectedIndex == 0) {
                context.removeSong();
            } else if (selectedIndex == 1) {
                context.removeArtist();
            } else if (selectedIndex == 2) {
                context.removeStation(context.currentPlayingStationId);
            }
        }
    }
    StationPlayerPopDialog {
        id: markSongDialog
        dialogAccept: qsTr("Ok")
        dialogTitle: qsTr("Add Song")
        dialogContent: qsTr("This song has been added to favorite list")
    }
    StationPlayerPopDialog {
        id: markSongErrorDialog
        dialogAccept: qsTr("Ok")
        dialogTitle: qsTr("Add Song")
        dialogContent: qsTr("Operation failed, please try again")
    }
}

