import QtQuick 1.0
import com.nokia.meego 1.0

// reimplement the selectdialog for the specify UI requirement
SelectionDialog {
    id: selectionDialog
    titleText: qsTr("Delete From Station")
    __drawFooterLine: true
    platformStyle: SelectionDialogStyle {
        commonLabelColor: "green"
    }
    title: Item {
        id: header
        height: selectionDialog.platformStyle.titleBarHeight
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
        anchors.bottom: parent.bottom
        Item {
            id: labelField
            anchors.fill:  parent
            Item {
                id: labelWrapper
                anchors.left: labelField.left
                anchors.right: closeButton.left
                anchors.bottom:  parent.bottom
                anchors.bottomMargin: selectionDialog.platformStyle.titleBarLineMargin
                //anchors.verticalCenter: labelField.verticalCenter
                height: titleLabel.height
                Label {
                    id: titleLabel
                    x: selectionDialog.platformStyle.titleBarIndent
                    width: parent.width - closeButton.width
                    //anchors.baseline:  parent.bottom
                    font: selectionDialog.platformStyle.titleBarFont
                    color: selectionDialog.platformStyle.commonLabelColor
                    elide: selectionDialog.platformStyle.titleElideMode
                    text: selectionDialog.titleText
                }
            }
            Image {
                id: closeButton
                anchors.bottom:  parent.bottom
                anchors.bottomMargin: selectionDialog.platformStyle.titleBarLineMargin-6
                //anchors.verticalCenter: labelField.verticalCenter
                anchors.right: labelField.right
                opacity: closeButtonArea.pressed ? 0.5 : 1.0
                source: "image://theme/icon-m-common-dialog-close"
                MouseArea {
                    id: closeButtonArea
                    anchors.fill: parent
                    onClicked:  {selectionDialog.reject();}
                }
            }
        }
        Rectangle {
            id: headerLine
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom:  header.bottom
            height: 3
            color: "green"
        }
    }
    buttons: Item {
        id: footer
        width: parent.width
        height: childrenRect.height
        //hack to make sure, we're evaluating the correct height
        Item {
            id: lineWrapper
            width: parent.width
            height: childrenRect.height
            y: 10
            Rectangle {
                id: footerLine

                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: parent.top
                height: selectionDialog.__drawFooterLine ? 3 : 0
                color: "green"
            }
        }
        //ugly hack to assure, that we're always evaluating the correct height
        Item {id: dummy; anchors.fill:  parent}
    }
    delegate: Component {
        id: defaultDelegate

        Item {
            id: delegateItem
            property bool selected: index == selectedIndex;
            height: root.platformStyle.itemHeight
            anchors.left: parent.left
            anchors.right: parent.right
            MouseArea {
                id: delegateMouseArea
                anchors.fill: parent;
                onPressed: selectedIndex = index;
                onClicked:  accept();
            }
            Rectangle {
                id: backgroundRect
                anchors.fill: parent
                color: delegateItem.selected ? root.platformStyle.itemSelectedBackgroundColor : root.platformStyle.itemBackgroundColor
            }
            BorderImage {
                id: background
                anchors.fill: parent
                border { left: 22; top: 22; right: 22; bottom: 22 }
                source: delegateMouseArea.pressed ? root.platformStyle.itemPressedBackground :
                        delegateItem.selected ? root.platformStyle.itemSelectedBackground :
                        root.platformStyle.itemBackground
            }
            Text {
                id: itemText
                elide: Text.ElideRight
                color: delegateItem.selected ? root.platformStyle.itemSelectedTextColor : root.platformStyle.itemTextColor
                anchors.verticalCenter: delegateItem.verticalCenter
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.leftMargin: root.platformStyle.itemLeftMargin
                anchors.rightMargin: root.platformStyle.itemRightMargin
                font: root.platformStyle.itemFont
                text: {
                    if (name === "Track Only") {
                        return qsTr("Track Only");
                    } else if (name === "Artist") {
                        return qsTr("Artist");
                    } else if (name === "Station") {
                        return qsTr("Station");
                    }
                }
            }
        }
    }
    model: ListModel {
        ListElement {name: "Track Only"}
        ListElement {name: "Artist"}
        ListElement {name: "Station"}
    }
}
