import QtQuick 1.0
import com.nokia.meego 1.0

Rectangle {
    width: parent.width
    height: parent.height
    id:suggestedFriends
    property string email: ""
    property string password: ""

    Image {
        id: bg
        source:  "../image/home_bg.png"
    }

    StationsTopBar {
        id: stationTopBar
        stationNameText: qsTr("Suggested Friends")
    }

    Text {
        id: reminder
        text: ""
        visible: false
        anchors.top: stationTopBar.bottom
        anchors.topMargin: 10
        anchors.left: parent.left
        anchors.leftMargin: 10
        color:"white"
        font.pixelSize: 20
    }

    FriendsList{
        id: friendsListView
        anchors.top: reminder.bottom
        anchors.bottom: friendsBottomBar.top
        anchors.topMargin: 20
        anchors.bottomMargin: 10
        anchors.left: parent.left
        needPressButton:true
        onItemClick: {
            context.addFriend("suggestedFriendsModel",index);
        }
    }

    Connections{
        target: context

        onGetSuggestedFriendsFinished:
        {
            indicator.running = false;
            indicator.visible = false;
            if(type===0)
            {
                friendsListView.listViewModel=suggestedFriendsModel;
                reminder.text=context.getSuggestedFriendsNumber()+qsTr(" already in Soundtracker");
                reminder.visible=true;
            }
            else
            {
                error.text=errorInfo;
                error.visible=true;
            }
        }
        onAddFriendFinished:
        {
            if(type===1)
            {
                errorDialog.dialogContent=errorInfo;
                errorDialog.open();
            }
            else
            {
                friendsListView.listViewModel=suggestedFriendsModel;
                reminder.text=context.getSuggestedFriendsNumber()+qsTr(" already in Soundtracker");
            }
        }
        onAddAllFriendsFinished:
        {
            if(type===0)
            {
                friendsListView.listViewModel=suggestedFriendsModel;
                reminder.text=context.getSuggestedFriendsNumber()+qsTr(" already in Soundtracker");
                reminder.visible=true;
            }
            else
            {
                errorDialog.dialogContent=errorInfo;
                errorDialog.open();
            }
        }

    }

    Text {
        id: error
        text: ""
        visible:false
        anchors.centerIn: parent
        color:"white"
        wrapMode: Text.WrapAnywhere
        font.pixelSize: 30
        font.bold: true
    }

    Item {
        id: playbackProgressBarArea
        width: parent.width
        height: playbackProgressBarAreaBg.sourceSize.height
        anchors.bottom: friendsBottomBar.top
        visible: {
            if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                return true;
            } else {
                return false;
            }
        }
        Image {
            id: playbackProgressBarAreaBg
            source: "../image/music_play_bg.png"
        }
        MediaPlaybackProgressBar {
            id: mediaPlaybackProgressBar
            anchors.verticalCenter: parent.verticalCenter
            value: context.currentPlayingPosition
            maximum: context.currentPlayingDuration
            leftmum: maximum - value
        }
    }

    FriendsBottomBar{
        id:friendsBottomBar
        anchors.bottom: parent.bottom
        strText: qsTr("Add all friends")
        strViewFirstItem:qsTr("Add all friends")
        strViewSecondItem:qsTr("Open player")
        onGoBack: {
            pageStack.pop();
        }
        onViewMenuItemClick:
        {
            switch(index)
            {
            case 0:
                context.addAllFriends();
                break;
            case 1:
                pageStack.push(Qt.resolvedUrl("StationPlayer.qml"));
                break;
            }
        }
        onButtonClick:
        {
            context.addAllFriends();
        }
    }

    BusyIndicator {
        id: indicator
        anchors.centerIn: friendsListView
        platformStyle: BusyIndicatorStyle { size: "large" }
        running: true
    }

    StationPlayerPopDialog {
        id: errorDialog
        dialogAccept: qsTr("Ok")
        dialogTitle: qsTr("Error")
        //dialogContent: qsTr("This song has been added to favorite list")
    }

    Component.onCompleted:
    {
        context.getSuggestedFriends();
    }
}
