import QtQuick 1.0
import com.nokia.meego 1.0
import "CommonUtil.js" as Util

Item {
    id: trackHistoryViewer
    width: parent.width
    height: parent.height


    Connections {
        target: context
        onGetTrackHistoryFinished: {
            indicator.running = false;
            indicator.visible = false;

            if(type === 0){
                songsList.model=trackHistoryModel;
            }
        }
    }

    Image {
        id: backgroudImg
        width: parent.width
        height: parent.height
        source: "../image/home_bg.png"
    }

    ListView {
        id:songsList
        width: parent.width
        anchors.top: pageTopBar.bottom
        anchors.bottom: pageBottomBar.top
        clip: true

        delegate: Item {
            width: ListView.view.width
            height: 100

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    //click one item
                }
            }

            Item {
                id: stationIcon
                anchors.left: parent.left
                anchors.leftMargin: 15
                width: 90;
                height: width;
                smooth: true
                Image {
                    id: defaultImage
                    width: parent.width - 2
                    height: width
                    anchors.centerIn: parent
                    source: Util.getRandomDefaultThumb();
                }
                Image {
                    id: stationImage
                    scale: 0.0
                    width: parent.width - 2
                    height: width
                    anchors.centerIn: parent
                    source: imageUrl
                }
            }

            Text {
                id: title
                anchors.top: parent.top
                anchors.topMargin: 10
                anchors.left: stationIcon.right
                anchors.leftMargin: 15
                anchors.right: parent.right
                color: "white"
                font.pixelSize: 20
                text: artist + " - " + name
                elide: Text.ElideRight
            }
            Text {
                id: albumDisplay
                anchors.left: stationIcon.right
                anchors.leftMargin: 15
                anchors.top: title.bottom
                anchors.right: parent.right
                color: "lightGray"
                font.pixelSize: 16
                text: qsTr("Album: ") + album
                elide: Text.ElideRight
            }
            Text {
                id: playedTime
                anchors.left: stationIcon.right
                anchors.leftMargin: 15
                anchors.top: albumDisplay.bottom
                color: "lightGray"
                font.pixelSize: 16
                elide: Text.ElideMiddle
                text: qsTr("Played: ") + playTs
            }
            states: [
                State {
                    name: "Show"; when: stationImage.status == Image.Ready
                    PropertyChanges { target: stationImage; scale: 1 }
                    PropertyChanges {target: defaultImage; visible: false}
                }
            ]
            transitions: [
                Transition {
                    NumberAnimation {
                        properties: "scale"; duration: 500; easing.type: Easing.InOutQuad
                    }

                }
            ]
        }
    }

    BusyIndicator {
        id: indicator
        anchors.centerIn: parent
        platformStyle: BusyIndicatorStyle { size: "large" }
        running: true
    }

    Image {
        id: pageTopBar
        width: parent.width
        anchors.top: parent.top
        source: "../image/top_bar.png"

        Text {
            anchors.left: parent.left
            anchors.leftMargin: 20
            anchors.verticalCenter: parent.verticalCenter
            font.pixelSize: 24
            color: "white"
            text: qsTr("Station's Track History")
        }
    }

    Item {
        id: playbackProgressBarArea
        width: parent.width
        height: playbackProgressBarAreaBg.sourceSize.height
        anchors.bottom: pageBottomBar.top
        visible: {
            if (context.mediaPlayerState == "playing" || context.mediaPlayerState == "paused") {
                return true;
            } else {
                return false;
            }
        }
        Image {
            id: playbackProgressBarAreaBg
            source: "../image/music_play_bg.png"
        }
        MediaPlaybackProgressBar {
            id: mediaPlaybackProgressBar
            anchors.verticalCenter: parent.verticalCenter
            value: context.currentPlayingPosition
            maximum: context.currentPlayingDuration
            leftmum: maximum - value
        }
    }

    StationsBottomBar {
        id: pageBottomBar
        anchors.bottom: parent.bottom

        onGoBack: {
            pageStack.pop();
        }
    }

    Component.onCompleted: {
        context.getTrackHistory();
    }
}
